@@ -13,7 +13,7 @@
 /************************************************************************/
 
 if (($radminsuper==1) OR ($radminarticle==1)) {
-    adminmenu("admin.php?op=adminStory", ""._ADDSTORY."", "postnew.gif");
+    adminmenu("admin.php?op=adminStory", ""._ADDSTORY."", "stories.gif");
 }
 	
 ?>
\ No newline at end of file
