@@ -13,7 +13,7 @@
 /************************************************************************/
 
 if (($radminsuper==1) OR ($radmindownload==1)) {
-    adminmenu("admin.php?op=downloads", ""._DOWNLOAD."", "download.gif");
+    adminmenu("admin.php?op=downloads", ""._DOWNLOAD."", "downloads.gif");
 }
 
 ?>
\ No newline at end of file
