@@ -31,16 +31,16 @@ function removeSubComments($tid) {
     if($numrows>0) {
 	while(list($stid) = sql_fetch_row($result, $dbi)) {
             removeSubComments($stid);
-            sql_query("delete from ".$prefix."_comments where tid=$stid", $dbi);
+            sql_query("delete from ".$prefix."_comments where tid='$stid'", $dbi);
         }
     }
-    sql_query("delete from ".$prefix."_comments where tid=$tid", $dbi);
+    sql_query("delete from ".$prefix."_comments where tid='$tid'", $dbi);
 }
 
 function removeComment ($tid, $sid, $ok=0) {
     global $ultramode, $prefix, $dbi;
     if($ok) {
-	$result = sql_query("select date from ".$prefix."_comments where pid=$tid", $dbi);
+	$result = sql_query("select date from ".$prefix."_comments where pid='$tid'", $dbi);
 	$numresults = sql_num_rows($result, $dbi);
         sql_query("update ".$prefix."_stories set comments=comments-1-'$numresults' where sid='$sid'", $dbi);
     /* Call recursive delete function to delete the comment and all its childs */
@@ -71,10 +71,10 @@ function removePollSubComments($tid) {
     if($numrows>0) {
 	while(list($stid) = sql_fetch_row($result, $dbi)) {
             removePollSubComments($stid);
-            sql_query("delete from ".$prefix."_pollcomments where tid=$stid", $dbi);
+            sql_query("delete from ".$prefix."_pollcomments where tid='$stid'", $dbi);
         }
     }
-    sql_query("delete from ".$prefix."_pollcomments where tid=$tid", $dbi);
+    sql_query("delete from ".$prefix."_pollcomments where tid='$tid'", $dbi);
 }
 
 function RemovePollComment ($tid, $pollID, $ok=0) {
