@@ -70,6 +70,13 @@ if ($jml <= 0) {
 	sql_query("insert into ".$prefix."_stats_month values('$nowYear','$i','0')",$dbi);
 	if ($i == 1) $TotalDay = 31;
 	if ($i == 2) {
+	    /*
+	    if (date("L") == true) {
+		$TotalDay = 29;
+	    } else {
+		$TotalDay = 28;
+	    }
+	    */
 	    if (($nowYear % 4) == 0) {
 		$TotalDay = 28;
 	    } else {
@@ -100,8 +107,6 @@ if (sql_num_rows($resulthour,$dbi) <= 0) {
     }
 }
 
-sql_free_result($resulthour, $dbi);
-
 sql_query("update ".$prefix."_stats_year set hits=hits+1 where year='$nowYear'",$dbi);
 sql_query("update ".$prefix."_stats_month set hits=hits+1 where (year='$nowYear') and (month='$nowMonth')",$dbi);
 sql_query("update ".$prefix."_stats_date set hits=hits+1 where (year='$nowYear') and (month='$nowMonth') and (date='$nowDate')",$dbi);
