@@ -17,7 +17,6 @@
 /* And, if you use HTML code, please double check it.                     */
 /**************************************************************************/
 
-
 define("_CHARSET","windows-1256");
 define("_SEARCH","");
 define("_LOGIN","");
@@ -37,16 +36,16 @@ define("_OLDERARTICLES"," ");
 define("_BY","");
 define("_ON","");
 define("_LOGOUT","");
-define("_WAITINGCONT","  ");
+define("_WAITINGCONT"," ");
 define("_SUBMISSIONS","");
 define("_WREVIEWS"," ");
 define("_WLINKS"," ");
-define("_EPHEMERIDS","Ephemerids");
+define("_EPHEMERIDS"," ");
 define("_ONEDAY","   ...");
 define("_ASREGISTERED","  Ͽ  <a href=\"modules.php?name=Your_Account\"></a>.      ,      .");
 define("_MENUFOR"," ");
-define("_NOBIGSTORY","There isn't a Biggest Story for Today, yet.");
-define("_BIGSTORY","Today's most read Story is:");
+define("_NOBIGSTORY","    .");
+define("_BIGSTORY","   :");
 define("_SURVEY","");
 define("_POLLS","");
 define("_PCOMMENTS",":");
@@ -60,7 +59,7 @@ define("_YOUHAVE"," ");
 define("_PRIVATEMSG"," .");
 define("_YOUAREANON","   .     <a href=\"modules.php?name=Your_Account\"></a>");
 define("_NOTE",":");
-define("_ADMIN","Admin:");
+define("_ADMIN"," :");
 define("_WERECEIVED"," ");
 define("_PAGESVIEWS","  ");
 define("_TOPIC","");
@@ -80,40 +79,82 @@ define("_RSSPROBLEM","       ");
 define("_SELECTLANGUAGE"," ");
 define("_SELECTGUILANG","  :");
 define("_NONE"," ");
-define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
-define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
-define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
-define("_NOACTIVEMODULES","Inactive Modules");
-define("_FORADMINTESTS","(for Admin tests)");
-define("_BBFORUMS","Forums");
-define("_ACCESSDENIED", "Access Denied");
-define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
-define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
-define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
-define("_HOME","Home");
-define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
-define("_ADDAHOME","Add a Module in your Home");
-define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
-define("_MORENEWS","More in News Section");
-define("_ALLCATEGORIES","All Categories");
-define("_DATESTRING","%A, %B %d @ %T %Z");
+define("_BLOCKPROBLEM","<center>    .</center>");
+define("_BLOCKPROBLEM2","<center>     .</center>");
+define("_MODULENOTACTIVE","   !");
+define("_NOACTIVEMODULES","  ");
+define("_FORADMINTESTS","(   )");
+define("_BBFORUMS","");
+define("_ACCESSDENIED", "  ");
+define("_RESTRICTEDAREA", "     .");
+define("_MODULEUSERS", "     <i>  </i><br><br>   <a href=\"user.php?op=new_user\"></a>,  <br>    .<br><br>");
+define("_MODULESADMINS", "      <i> </i><br><br>");
+define("_HOME"," ");
+define("_HOMEPROBLEM"," :    !!!");
+define("_ADDAHOME","     ");
+define("_HOMEPROBLEMUSER","     .    .");
+define("_MORENEWS","    ");
+define("_ALLCATEGORIES"," ");
+define("_DATESTRING","%A, %B %d");
 define("_DATESTRING2","%A, %B %d");
-define("_DATE","Date");
-define("_HOUR","Hour");
-define("_UMONTH","Month");
-define("_YEAR","Year");
-define("_JANUARY","January");
-define("_FEBRUARY","February");
-define("_MARCH","March");
-define("_APRIL","April");
-define("_MAY","May");
-define("_JUNE","June");
-define("_JULY","July");
-define("_AUGUST","August");
-define("_SEPTEMBER","September");
-define("_OCTOBER","October");
-define("_NOVEMBER","November");
-define("_DECEMBER","December");
+define("_DATE","");
+define("_HOUR","");
+define("_UMONTH","");
+define("_YEAR","");
+define("_JANUARY","");
+define("_FEBRUARY","");
+define("_MARCH","");
+define("_APRIL","");
+define("_MAY","");
+define("_JUNE","");
+define("_JULY","");
+define("_AUGUST","");
+define("_SEPTEMBER","");
+define("_OCTOBER","");
+define("_NOVEMBER","");
+define("_DECEMBER","");
+define("_BWEL","");
+define("_BPM"," ");
+define("_BUNREAD"," ");
+define("_BREAD","");
+define("_BMEMP","");
+define("_BLATEST","");
+define("_BTD"," ");
+define("_BYD"," ");
+define("_BOVER","");
+define("_BVISIT"," ");
+define("_BVIS","");
+define("_BMEM","");
+define("_BTT","");
+define("_BON"," ");
+define("_BREG","");
+define("_BROADCAST","  ");
+define("_BROADCASTFROM","  ");
+define("_TURNOFFMSG","  ");
+define("_JOURNAL","");
+define("_READMYJOURNAL"," ");
+define("_ADD","");
+define("_YES","");
+define("_NO","");
+define("_INVISIBLEMODULES","  ");
+define("_ACTIVEBUTNOTSEE","(   )");
+define("_THISISAUTOMATED","          .");
+define("_THERESULTS","   :");
+define("_TOTALIMPRESSIONS"," :");
+define("_CLICKSRECEIVED"," :");
+define("_IMAGEURL"," ");
+define("_CLICKURL"," :");
+define("_ALTERNATETEXT"," :");
+define("_HOPEYOULIKED","           .");
+define("_THANKSUPPORT","  ");
+define("_TEAM"," ");
+define("_BANNERSFINNISHED"," ");
+define("_MODREQLINKS"," ");
+define("_BROKENLINKS","  ");
+define("_MODREQDOWN"," ");
+define("_BROKENDOWN","  ");
+define("_PAGEGENERATION"," :");
+define("_SECONDS","");
 
 /*****************************************************/
 /* Function to translate Datestrings                 */
