@@ -1,5 +1,4 @@
 <?php
-
 /**************************************************************************/
 /* PHP-NUKE: Advanced Content Management System                           */
 /* ============================================                           */
@@ -17,7 +16,6 @@
 /* And, if you use HTML code, please double check it.                     */
 /**************************************************************************/
 
-
 define("_CHARSET","ISO-8859-1");
 define("_SEARCH","Zoek");
 define("_LOGIN","Inloggen");
@@ -32,14 +30,14 @@ define("_POSTEDBY","Geplaatst door");
 define("_READS","maal gelezen");
 define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Ga terug</a> ]");
 define("_COMMENTS","opmerkingen");
-define("_PASTARTICLES","Voorgaande artikelen");
+define("_PASTARTICLES","Vorige artikelen");
 define("_OLDERARTICLES","Oudere artikelen");
 define("_BY","door");
 define("_ON","op");
 define("_LOGOUT","Afmelden");
 define("_WAITINGCONT","Wachtende inhoud");
 define("_SUBMISSIONS","Ingeleverde stukken");
-define("_WREVIEWS","Wachtende reviews");
+define("_WREVIEWS","Wachtende periodieken");
 define("_WLINKS","Wachtende links");
 define("_EPHEMERIDS","Ephemerids");
 define("_ONEDAY","Een dag zoals vandaag...");
@@ -51,7 +49,7 @@ define("_SURVEY","Onderzoek");
 define("_POLLS","Peilingen");
 define("_PCOMMENTS","Opmerkingen:");
 define("_RESULTS","Uitslagen");
-define("_HREADMORE","Lees Meer...");
+define("_HREADMORE","Lees meer...");
 define("_CURRENTLY","Er zijn op dit moment,");
 define("_GUESTS","gast(en) en");
 define("_MEMBERS","lid(leden) die online zijn.");
@@ -82,38 +80,80 @@ define("_SELECTGUILANG","Kies interface taal:");
 define("_NONE","Geen");
 define("_BLOCKPROBLEM","<center>Er is een probleem met dit blok.</center>");
 define("_BLOCKPROBLEM2","<center>Dit blok heeft geen inhoud.</center>");
-define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
-define("_NOACTIVEMODULES","Inactive Modules");
-define("_FORADMINTESTS","(for Admin tests)");
+define("_MODULENOTACTIVE","Sorry, deze module is niet actief");
+define("_NOACTIVEMODULES","Inactieve Modules");
+define("_FORADMINTESTS","(voor Admin testen)");
 define("_BBFORUMS","Forums");
-define("_ACCESSDENIED", "Access Denied");
-define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
-define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
-define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
-define("_HOME","Home");
-define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
-define("_ADDAHOME","Add a Module in your Home");
-define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
-define("_MORENEWS","More in News Section");
-define("_ALLCATEGORIES","All Categories");
-define("_DATESTRING","%A %d %B @ %T %Z");
+define("_ACCESSDENIED", "Geen Toegang");
+define("_RESTRICTEDAREA", "Voorbehouden zone.");
+define("_MODULEUSERS", "Onze verontschuldigingen, dit onderdeel is enkel toegankelijk voor <i>geregistreerde bezoekers</i><br><br>Je kan gratis registreren door <a href=\"modules.php?name=Your_Account&op=new_user\">hier</a> te klikken,<br>daarna kan je dit onderdeel raadplegen zonder beperkingen.<br>Dank u.<br><br>");
+define("_MODULESADMINS", "Onze verontschuldigingen, dit onderdeel is enkel toegankelijk voor <i>Beheerders</i><br><br>");
+define("_HOME","Startpagina");
+define("_HOMEPROBLEM","Oei... Probleem... Hier is geen startpagina!");
+define("_ADDAHOME","Module toevoegen op startpagina");
+define("_HOMEPROBLEMUSER","Er is een probleem op de startpagina. Gelieve dit nadien te controleren.");
+define("_MORENEWS","Meer in het onderdeel NIEUWS");
+define("_ALLCATEGORIES","Alle categorien");
+define("_DATESTRING","%A %d %B @ %T GMT+1");
 define("_DATESTRING2","%A %d %B");
-define("_DATE","Date");
-define("_HOUR","Hour");
-define("_UMONTH","Month");
-define("_YEAR","Year");
-define("_JANUARY","January");
-define("_FEBRUARY","February");
-define("_MARCH","March");
+define("_DATE","Datum");
+define("_HOUR","Uur");
+define("_UMONTH","Maand");
+define("_YEAR","Jaar");
+define("_JANUARY","Januari");
+define("_FEBRUARY","Februari");
+define("_MARCH","Maart");
 define("_APRIL","April");
-define("_MAY","May");
-define("_JUNE","June");
-define("_JULY","July");
-define("_AUGUST","August");
+define("_MAY","Mei");
+define("_JUNE","Juni");
+define("_JULY","Juli");
+define("_AUGUST","Augustus");
 define("_SEPTEMBER","September");
-define("_OCTOBER","October");
+define("_OCTOBER","Oktober");
 define("_NOVEMBER","November");
 define("_DECEMBER","December");
+define("_BWEL","Welkom");
+define("_BPM","Priv-berichten");
+define("_BUNREAD","Ongelezen");
+define("_BREAD","Lees");
+define("_BMEMP","Lidmaatschap");
+define("_BLATEST","Laatste");
+define("_BTD","Nieuw vandaag");
+define("_BYD","Nieuw gisteren");
+define("_BOVER","Algemeen");
+define("_BVISIT","Bezoekers Online");
+define("_BVIS","Bezoekers");
+define("_BMEM","Leden");
+define("_BTT","Totaal");
+define("_BON","Nu Online");
+define("_BREG","Registreer");
+define("_BROADCAST","Uitgezonden Publieke Berichten");
+define("_BROADCASTFROM","Publieke Berichten van");
+define("_TURNOFFMSG","Zet Publieke Berichten uit");
+define("_JOURNAL","Journaal");
+define("_READMYJOURNAL","Lees mijn Journaal");
+define("_ADD","Toevoegen");
+define("_YES","Ja");
+define("_NO","Nee");
+define("_INVISIBLEMODULES","Onzichtbare Modules");
+define("_ACTIVEBUTNOTSEE","(Actieve maar onzichtbare link)");
+define("_THISISAUTOMATED","Dit is een automatisch E-mail om u te laten weten dat uw banner advertering in uw site nu beindigd is.");
+define("_THERESULTS","De resultaten van uw campagne zijn als volgt:");
+define("_TOTALIMPRESSIONS","Totaal gemaakte Impressies:");
+define("_CLICKSRECEIVED","Kliks ontvangen:");
+define("_IMAGEURL","Beeld URL");
+define("_CLICKURL","Klik URL:");
+define("_ALTERNATETEXT","Alternatieve Tekst:");
+define("_HOPEYOULIKED","Hopelijks bent u tevreden over onze diensten. Wij zouden u graag wederom verwelkomen als adverteerder.");
+define("_THANKSUPPORT","Bedankt voor uw Support");
+define("_TEAM","Team");
+define("_BANNERSFINNISHED","Banners Toevoegingen Beindigd");
+define("_MODREQLINKS","Bewerk Links");
+define("_BROKENLINKS","Gebroken Links");
+define("_MODREQDOWN","Bewerk Downloads");
+define("_BROKENDOWN","Gebroken Downloads");
+define("_PAGEGENERATION","Pagina Rendering:");
+define("_SECONDS","Seconden");
 
 /*****************************************************/
 /* Function to translate Datestrings                 */
@@ -129,4 +169,4 @@ function translate($phrase) {
     return $tmp;
 }
 
-?>
\ No newline at end of file
+?>
