@@ -1,5 +1,4 @@
 <?php
-
 /**************************************************************************/
 /* PHP-NUKE: Advanced Content Management System                           */
 /* ============================================                           */
@@ -17,7 +16,6 @@
 /* And, if you use HTML code, please double check it.                     */
 /**************************************************************************/
 
-
 define("_CHARSET","ISO-8859-1");
 define("_SEARCH","Search");
 define("_LOGIN","Login");
@@ -43,7 +41,7 @@ define("_WREVIEWS","Waiting Reviews");
 define("_WLINKS","Waiting Links");
 define("_EPHEMERIDS","Ephemerids");
 define("_ONEDAY","One Day like Today...");
-define("_ASREGISTERED","Don't have an account yet? You can <a href=\"modules.php?name=Your_Account\">create one</a>. As registered user you have some advantages like theme manager, comments configuration and post comments with your name.");
+define("_ASREGISTERED","Don't have an account yet? You can <a href=\"modules.php?name=Your_Account\">create one</a>. As a registered user you have some advantages like theme manager, comments configuration and post comments with your name.");
 define("_MENUFOR","Menu for");
 define("_NOBIGSTORY","There isn't a Biggest Story for Today, yet.");
 define("_BIGSTORY","Today's most read Story is:");
@@ -87,13 +85,13 @@ define("_NOACTIVEMODULES","Inactive Modules");
 define("_FORADMINTESTS","(for Admin tests)");
 define("_BBFORUMS","Forums");
 define("_ACCESSDENIED", "Access Denied");
-define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
-define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
-define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
+define("_RESTRICTEDAREA", "You are trying to access a restricted area.");
+define("_MODULEUSERS", "We are Sorry, but this section of our site is for <i>Registered Users Only.</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access this section without restrictions. Thanks.<br><br>");
+define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only.</i><br><br>");
 define("_HOME","Home");
-define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
+define("_HOMEPROBLEM","There is a big problem here: we do not have a Homepage!!!");
 define("_ADDAHOME","Add a Module in your Home");
-define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
+define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check back later.");
 define("_MORENEWS","More in News Section");
 define("_ALLCATEGORIES","All Categories");
 define("_DATESTRING","%A, %B %d @ %T %Z");
@@ -114,6 +112,52 @@ define("_SEPTEMBER","September");
 define("_OCTOBER","October");
 define("_NOVEMBER","November");
 define("_DECEMBER","December");
+define("_BWEL","Welcome");
+define("_BPM","Private Messages");
+define("_BUNREAD","Unread");
+define("_BREAD","Read");
+define("_BMEMP","Membership");
+define("_BLATEST","Latest");
+define("_BTD","New Today");
+define("_BYD","New Yesterday");
+define("_BOVER","Overall");
+define("_BVISIT","People Online");
+define("_BVIS","Visitors");
+define("_BMEM","Members");
+define("_BTT","Total");
+define("_BON","Online Now");
+define("_BREG","Register");
+define("_BROADCAST","Broadcast Public Message");
+define("_BROADCASTFROM","Public Message from");
+define("_TURNOFFMSG","Turn Off Public Messages");
+define("_JOURNAL","Journal");
+define("_READMYJOURNAL","Read My Journal");
+define("_ADD","Add");
+define("_YES","Yes");
+define("_NO","No");
+define("_INVISIBLEMODULES","Invisible Modules");
+define("_ACTIVEBUTNOTSEE","(Active but invisible link)");
+define("_THISISAUTOMATED","This is an automated email to let you know that your banner advertising in our site has been completed.");
+define("_THERESULTS","The results of your campaign are as follows:");
+define("_TOTALIMPRESSIONS","Total Impression Made:");
+define("_CLICKSRECEIVED","Clicks Received:");
+define("_IMAGEURL","Image URL");
+define("_CLICKURL","Click URL:");
+define("_ALTERNATETEXT","Alternate Text:");
+define("_HOPEYOULIKED","Hope you liked our service. We'll look forward to having you as an advertising customer again soon.");
+define("_THANKSUPPORT","Thanks for your Support");
+define("_TEAM","Team");
+define("_BANNERSFINNISHED","Banners Ads Finished");
+define("_MODREQLINKS","Mod. Links");
+define("_BROKENLINKS","Broken Links");
+define("_MODREQDOWN","Mod. Downloads");
+define("_BROKENDOWN","Broken Downloads");
+define("_PAGEGENERATION","Page Generation:");
+define("_SECONDS","Seconds");
+define("_YOUHAVEONEMSG","You Have 1 New Private Message");
+define("_YOUHAVE","You Have");
+define("_NEWPMSG","New Private Messages");
+define("_CONTRIBUTEDBY","Contributed by");
 
 /*****************************************************/
 /* Function to translate Datestrings                 */
