@@ -14,8 +14,27 @@ ob_start("ob_gzhandler");
 /* the Free Software Foundation; either version 2 of the License.       */
 /************************************************************************/
 
+if (!ini_get("register_globals")) {
+    $php_ver = phpversion();
+    $php_ver = explode(".", $php_ver);
+    $phpver = "$php_ver[0]$php_ver[1]";
+    if ($phpver >= 41) {
+	$PHP_SELF = $_SERVER['PHP_SELF'];
+	import_request_variables('GPC');
+    }
+}
+
 foreach ($HTTP_GET_VARS as $secvalue) {
-    if (eregi("<[^>]*script*\"?[^>]*>", $secvalue)) {
+    if ((eregi("<[^>]*script*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*object*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*iframe*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*applet*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*meta*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*style*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*form*\"?[^>]*>", $secvalue)) ||
+	(eregi("<[^>]*img*\"?[^>]*>", $secvalue)) ||
+	(eregi("\([^>]*\"?[^)]*\)", $secvalue)) ||
+	(eregi("\"", $secvalue))) {
 	die ("I don't like you...");
     }
 }
@@ -29,6 +48,14 @@ require_once("config.php");
 require_once("includes/sql_layer.php");
 $dbi = sql_connect($dbhost, $dbuname, $dbpass, $dbname);
 $mainfile = 1;
+$result = sql_query("SELECT sitename, nukeurl, site_logo, slogan, startdate, adminmail, anonpost, Default_Theme, foot1, foot2, foot3, commentlimit, anonymous, minpass, pollcomm, articlecomm, broadcast_msg, my_headlines, top, storyhome, user_news, oldnum, ultramode, banners, backend_title, backend_language, language, locale, multilingual, useflags, notify, notify_email, notify_subject, notify_message, notify_from, footermsgtxt, email_send, attachmentdir, attachments, attachments_view, download_dir, defaultpopserver, singleaccount, singleaccountname, numaccounts, imgpath, filter_forward, moderate, admingraphic, httpref, httprefmax, CensorMode, CensorReplace, copyright, Version_Num from ".$prefix."_config", $dbi);
+list($sitename, $nukeurl, $site_logo, $slogan, $startdate, $adminmail, $anonpost, $Default_Theme, $foot1, $foot2, $foot3, $commentlimit, $anonymous, $minpass, $pollcomm, $articlecomm, $broadcast_msg, $my_headlines, $top, $storyhome, $user_news, $oldnum, $ultramode, $banners, $backend_title, $backend_language, $language, $locale, $multilingual, $useflags, $notify, $notify_email, $notify_subject, $notify_message, $notify_from, $footermsgtxt, $email_send, $attachmentdir, $attachments, $attachments_view, $download_dir, $defaultpopserver, $singleaccount, $singleaccountname, $numaccounts, $imgpath, $filter_forward, $moderate, $admingraphic, $httpref, $httprefmax, $CensorMode, $CensorReplace, $copyright, $Version_Num) = sql_fetch_row($result, $dbi);
+$domain = eregi_replace("http://", "", $nukeurl);
+$tipath = "images/topics/";
+$mtime = microtime();
+$mtime = explode(" ",$mtime);
+$mtime = $mtime[1] + $mtime[0];
+$starttime = $mtime;
 
 if (isset($newlang)) {
     if (file_exists("language/lang-$newlang.php")) {
@@ -50,14 +77,18 @@ if (isset($newlang)) {
 }
 
 function get_lang($module) {
-    global $currentlang;
-    if ($module == admin) {
-	if (file_exists("admin/language/lang-$currentlang.php")) {
+    global $currentlang, $language;
+    if (file_exists("modules/$module/language/lang-$currentlang.php")) {
+	if ($module == admin) {
 	    include_once("admin/language/lang-$currentlang.php");
+	} else {
+	    include_once("modules/$module/language/lang-$currentlang.php");
 	}
     } else {
-	if (file_exists("modules/$module/language/lang-$currentlang.php")) {	
-	    include_once("modules/$module/language/lang-$currentlang.php");
+	if ($module == admin) {
+	    include_once("admin/language/lang-$currentlang.php");
+	} else {
+	    include_once("modules/$module/language/lang-$language.php");
 	}
     }
 }
@@ -73,10 +104,12 @@ function is_admin($admin) {
         $aid = "$admin[0]";
 	$pwd = "$admin[1]";
     }
-    $result = sql_query("select pwd from ".$prefix."_authors where aid='$aid'", $dbi);
-    list($pass) = sql_fetch_row($result, $dbi);
-    if($pass == $pwd && $pass != "") {
-	return 1;
+    if ($aid != "" AND $pwd != "") {
+	$result = sql_query("select pwd from ".$prefix."_authors where aid='$aid'", $dbi);
+	list($pass) = sql_fetch_row($result, $dbi);
+	if($pass == $pwd && $pass != "") {
+	    return 1;
+	}
     }
     return 0;
 }
@@ -92,14 +125,17 @@ function is_user($user) {
         $uid = "$user[0]";
 	$pwd = "$user[2]";
     }
-    $result = sql_query("select pass from ".$user_prefix."_users where uid='$uid'", $dbi);
-    list($pass) = sql_fetch_row($result, $dbi);
-    if($pass == $pwd && $pass != "") {
-	return 1;
+    if ($uid != "" AND $pwd != "") {
+	$result = sql_query("select pass from ".$user_prefix."_users where uid='$uid'", $dbi);
+	list($pass) = sql_fetch_row($result, $dbi);
+	if($pass == $pwd && $pass != "") {
+	    return 1;
+	}
     }
     return 0;
 }
 
+
 function title($text) {
     OpenTable();
     echo "<center><font class=\"title\"><b>$text</b></font></center>";
@@ -123,18 +159,22 @@ function render_blocks($side, $blockfile, $title, $content, $bid, $url) {
 	if ($blockfile == "") {
 	    if ($side == "c") {
 		themecenterbox($title, $content);
+	    } elseif ($side == "d") {
+		themecenterbox($title, $content);
 	    } else {
 		themesidebox($title, $content);
 	    }
 	} else {
 	    if ($side == "c") {
 		blockfileinc($title, $blockfile, 1);
+	    } elseif ($side == "d") {
+		themecenterbox($title, $content);
 	    } else {
 		blockfileinc($title, $blockfile);
 	    }
 	}
     } else {
-	if ($side == "c") {
+	if ($side == "c" OR $side == "d") {
 	    headlines($bid,1);
 	} else {
     	    headlines($bid);
@@ -155,6 +195,8 @@ function blocks($side) {
 	$pos = "r";
     }  elseif (strtolower($side[0]) == "c") {
 	$pos = "c";
+    } elseif  (strtolower($side[0]) == "d") {
+	$pos = "d";
     }
     $side = $pos;
     $result = sql_query("select bid, bkey, title, content, url, blockfile, view from ".$prefix."_blocks where position='$pos' AND active='1' $querylang ORDER BY weight ASC", $dbi);
@@ -203,14 +245,14 @@ function message_box() {
 	    }
 	    if ($view == 4 AND is_admin($admin)) {
                 OpenTable();
-                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center>\n"
+                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center><br>\n"
 		    ."<font class=\"content\">$content</font>"
 		    ."<br><br><center><font class=\"content\">[ "._MVIEWADMIN." - $remain - <a href=\"admin.php?op=editmsg&mid=$mid\">"._EDIT."</a> ]</font></center>";
 		CloseTable();
 		echo "<br>";
 	    } elseif ($view == 3 AND is_user($user) || is_admin($admin)) {
                 OpenTable();
-                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center>\n"
+                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center><br>\n"
 		    ."<font class=\"content\">$content</font>";
 		if (is_admin($admin)) {
 		    echo "<br><br><center><font class=\"content\">[ "._MVIEWUSERS." - $remain - <a href=\"admin.php?op=editmsg&mid=$mid\">"._EDIT."</a> ]</font></center>";
@@ -219,7 +261,7 @@ function message_box() {
 		echo "<br>";
 	    } elseif ($view == 2 AND !is_user($user) || is_admin($admin)) {
                 OpenTable();
-                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center>\n"
+                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center><br>\n"
 		    ."<font class=\"content\">$content</font>";
 		if (is_admin($admin)) {
 		    echo "<br><br><center><font class=\"content\">[ "._MVIEWANON." - $remain - <a href=\"admin.php?op=editmsg&mid=$mid\">"._EDIT."</a> ]</font></center>";
@@ -228,7 +270,7 @@ function message_box() {
 		echo "<br>";
 	    } elseif ($view == 1) {
                 OpenTable();
-                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center>\n"
+                echo "<center><font class=\"option\" color=\"$textcolor2\"><b>$title</b></font></center><br>\n"
 		    ."<font class=\"content\">$content</font>";
 		if (is_admin($admin)) {
 		    echo "<br><br><center><font class=\"content\">[ "._MVIEWALL." - $remain - <a href=\"admin.php?op=editmsg&mid=$mid\">"._EDIT."</a> ]</font></center>";
@@ -280,6 +322,8 @@ function blockfileinc($title, $blockfile, $side=0) {
     }
     if ($side == 1) {
 	themecenterbox($blockfiletitle, $content);
+    } elseif ($side == 2) {
+	themecenterbox($blockfiletitle, $content);
     } else {
 	themesidebox($blockfiletitle, $content);
     }
@@ -304,7 +348,7 @@ function selectlanguage() {
 	    $tl = ereg_replace("lang-","",$menulist[$i]);
 	    $tl = ereg_replace(".php","",$tl);
 	    $altlang = ucfirst($tl);
-	    $content .= "<a href=\"index.php?newlang=$tl\"><img src=\"images/language/flag-$tl.png\" border=\"0\" alt=\"$altlang\" hspace=\"3\" vspace=\"3\"></a> ";
+	    $content .= "<a href=\"index.php?newlang=$tl\"><img src=\"images/language/flag-$tl.png\" border=\"0\" alt=\"$altlang\" title=\"$altlang\" hspace=\"3\" vspace=\"3\"></a> ";
 	}
     }
     $content .= "</font></center>";
@@ -342,7 +386,7 @@ function ultramode() {
     fwrite($file, "General purpose self-explanatory file with news headlines\n");
     $rfile=sql_query("select sid, aid, title, time, comments, topic from ".$prefix."_stories order by time DESC limit 0,10", $dbi);
     while(list($sid, $aid, $title, $time, $comments, $topic) = sql_fetch_row($rfile, $dbi)) {
-	$rfile2=sql_query("select topictext, topicimage from ".$prefix."_topics where topicid=$topic", $dbi);
+	$rfile2=sql_query("select topictext, topicimage from ".$prefix."_topics where topicid='$topic'", $dbi);
 	list($topictext, $topicimage) = sql_fetch_row($rfile2, $dbi);
 	$content = "%%\n$title\n/modules.php?name=News&file=article&sid=$sid\n$time\n$aid\n$topictext\n$comments\n$topicimage\n";
 	fwrite($file, $content);
@@ -368,24 +412,13 @@ function getusrinfo($user) {
     global $userinfo, $user_prefix, $dbi;
     $user2 = base64_decode($user);
     $user3 = explode(":", $user2);
-    $result = sql_query("select uid, name, uname, email, femail, url, user_avatar, user_icq, user_occ, user_from, user_intrest, user_sig, user_viewemail, user_theme, user_aim, user_yim, user_msnm, pass, storynum, umode, uorder, thold, noscore, bio, ublockon, ublock, theme, commentmax, newsletter from ".$user_prefix."_users where uname='$user3[1]' and pass='$user3[2]'", $dbi);
+    $result = sql_query("select uid, name, uname, email, femail, url, user_avatar, user_icq, user_occ, user_from, user_intrest, user_sig, user_viewemail, user_theme, user_aim, user_yim, user_msnm, pass, storynum, umode, uorder, thold, noscore, bio, ublockon, ublock, theme, commentmax, newsletter, broadcast, popmeson from ".$user_prefix."_users where uname='$user3[1]' and pass='$user3[2]'", $dbi);
     if (sql_num_rows($result, $dbi) == 1) {
     	$userinfo = sql_fetch_array($result, $dbi);
     }
     return $userinfo;
 }
 
-function searchblock() {
-    OpenTable();
-    echo "<form action=\"modules.php?name=Forum&file=search\" method=\"post\">";
-    echo "<input type=\"hidden\" name=\"addterm\" value=\"any\">";
-    echo "<input type=\"hidden\" name=\"sortby\" value=\"p.post_time\">";
-    echo "&nbsp;&nbsp;<b>"._SEARCH."</b>&nbsp;<input type=\"text\" name=\"term\" size=\"15\">";
-    echo "<input type=\"hidden\" name=\"submit\" value=\"submit\"></form>";
-    echo "<div align=\"left\"><font class=\"content\">&nbsp;&nbsp;[ <a href=\"modules.php?name=Forum&file=search&addterm=any&amp;sortby=p.post_time&amp;adv=1\">Advanced Search</a> ]</font></div>";
-    CloseTable();
-}
-
 function FixQuotes ($what = "") {
 	$what = ereg_replace("'","''",$what);
 	while (eregi("\\\\'", $what)) {
@@ -486,8 +519,8 @@ function check_html ($str, $strip="") {
 	$str = eregi_replace("<a[^>]*href[[:space:]]*=[[:space:]]*\"?[[:space:]]*([^\" >]*)[[:space:]]*\"?[^>]*>",
                          '<a href="\\1">', $str); # "
                // Delete all attribs from Anchor, except an href, double quoted.
-	$str = eregi_replace("<img?",
-                         '', $str); # "
+	$str = eregi_replace("<[[:space:]]* img[[:space:]]*([^>]*)[[:space:]]*>", '', $str);
+	       // Delete all img tags
 	$tmp = "";
 	while (ereg("<(/?[[:alpha:]]*)[[:space:]]*([^>]*)>",$str,$reg)) {
 		$i = strpos($str,$reg[0]);
@@ -586,24 +619,28 @@ function adminblock() {
     global $admin, $prefix, $dbi;
     if (is_admin($admin)) {
 	$result = sql_query("select title, content from ".$prefix."_blocks where bkey='admin'", $dbi);
-	while(list($title, $content) = sql_fetch_array($result, $dbi)) {
+	while(list($title, $content) = sql_fetch_row($result, $dbi)) {
 	    $content = "<font class=\"content\">$content</font>";
 	    themesidebox($title, $content);
 	}
 	$title = ""._WAITINGCONT."";
-	$result = sql_query("select * from ".$prefix."_queue", $dbi);
-	$num = sql_num_rows($result, $dbi);
+	$num = sql_num_rows(sql_query("select * from ".$prefix."_queue", $dbi), $dbi);
 	$content = "<font class=\"content\">";
 	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=submissions\">"._SUBMISSIONS."</a>: $num<br>";
-	$result = sql_query("select * from ".$prefix."_reviews_add", $dbi);
-	$num = sql_num_rows($result, $dbi);
+	$num = sql_num_rows(sql_query("select * from ".$prefix."_reviews_add", $dbi), $dbi);
 	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=reviews\">"._WREVIEWS."</a>: $num<br>";
-	$result = sql_query("select * from ".$prefix."_links_newlink", $dbi);
-	$num = sql_num_rows($result, $dbi);
+	$num = sql_num_rows(sql_query("select * from ".$prefix."_links_newlink", $dbi), $dbi);
+	$brokenl = sql_num_rows(sql_query("select * from ".$prefix."_links_modrequest where brokenlink='1'", $dbi), $dbi);
+	$modreql = sql_num_rows(sql_query("select * from ".$prefix."_links_modrequest where brokenlink='0'", $dbi), $dbi);
 	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=Links\">"._WLINKS."</a>: $num<br>";
-	$result = sql_query("select * from ".$prefix."_downloads_newdownload", $dbi);
-	$num = sql_num_rows($result, $dbi);
-	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=downloads\">"._UDOWNLOADS."</a>: $num<br></font>";
+	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=LinksListModRequests\">"._MODREQLINKS."</a>: $modreql<br>";
+	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=LinksListBrokenLinks\">"._BROKENLINKS."</a>: $brokenl<br>";
+	$num = sql_num_rows(sql_query("select * from ".$prefix."_downloads_newdownload", $dbi), $dbi);
+	$brokend = sql_num_rows(sql_query("select * from ".$prefix."_downloads_modrequest where brokendownload='1'", $dbi), $dbi);
+	$modreqd = sql_num_rows(sql_query("select * from ".$prefix."_downloads_modrequest where brokendownload='0'", $dbi), $dbi);
+	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=downloads\">"._UDOWNLOADS."</a>: $num<br>";
+	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=DownloadsListModRequests\">"._MODREQDOWN."</a>: $modreqd<br>";
+	$content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=DownloadsListBrokenDownloads\">"._BROKENDOWN."</a>: $brokend<br></font>";
 	themesidebox($title, $content);
     }
 }
@@ -637,9 +674,9 @@ function userblock() {
 function getTopics($s_sid) {
     global $topicname, $topicimage, $topictext, $prefix, $dbi;
     $sid = $s_sid;
-    $result = sql_query("SELECT topic FROM ".$prefix."_stories where sid=$sid", $dbi);
+    $result = sql_query("SELECT topic FROM ".$prefix."_stories where sid='$sid'", $dbi);
     list($topic) = sql_fetch_row($result, $dbi);
-    $result = sql_query("SELECT topicid, topicname, topicimage, topictext FROM ".$prefix."_topics where topicid=$topic", $dbi);
+    $result = sql_query("SELECT topicid, topicname, topicimage, topictext FROM ".$prefix."_topics where topicid='$topic'", $dbi);
     list($topicid, $topicname, $topicimage, $topictext) = sql_fetch_row($result, $dbi);
 }
 
@@ -654,7 +691,6 @@ function headlines($bid, $cenbox=0) {
 	$fp = fsockopen($rdf['host'], 80, $errno, $errstr, 15);
 	if (!$fp) {
 	    $content = "";
-	    //$content = "<font class=\"content\">"._RSSPROBLEM."</font>";
 	    $result = sql_query("update ".$prefix."_blocks set content='$content', time='$btime' where bid='$bid'", $dbi);
 	    $cont = 0;
 	    if ($cenbox == 0) {
@@ -681,7 +717,7 @@ function headlines($bid, $cenbox=0) {
 		$link = ereg_replace("</link>.*","",$link);
 		$title2 = ereg_replace(".*<title>","",$items[$i]);
 		$title2 = ereg_replace("</title>.*","",$title2);
-		if ($items[$i] == "") {
+		if ($items[$i] == "" AND $cont != 1) {
 		    $content = "";
 		    sql_query("update ".$prefix."_blocks set content='$content', time='$btime' where bid='$bid'", $dbi);
 		    $cont = 0;
@@ -692,7 +728,7 @@ function headlines($bid, $cenbox=0) {
 		    }
 		    return;
 		} else {
-		    if (strcmp($link,$title)) {
+		    if (strcmp($link,$title2) AND $items[$i] != "") {
 			$cont = 1;
 			$content .= "<strong><big>&middot;</big></strong><a href=\"$link\" target=\"new\">$title2</a><br>\n";
 		    }
@@ -763,4 +799,75 @@ function themecenterbox($title, $content) {
     echo "<br>";
 }
 
+function public_message() {
+    global $prefix, $user_prefix, $dbi, $user, $admin, $p_msg, $cookie, $broadcast_msg;
+    if ($broadcast_msg == 1) {
+    if (is_user($user)) {
+        cookiedecode($user);
+	$result = sql_query("select broadcast from ".$user_prefix."_users where uname='$cookie[1]'", $dbi);
+	list ($upref) = sql_fetch_row($result, $dbi);
+	if ($upref == 1) {
+	    $t_off = "<br><p align=\"right\">[ <a href=\"modules.php?name=Your_Account&amp;op=edithome\"><font color=\"FFFFFF\" size=\"2\">"._TURNOFFMSG."</font></a> ]</font>";
+	    $pm_show = 1;
+	} else {
+	    $pm_show = 0;
+	}
+    } else {
+	$t_off = "";
+    }
+    if (!is_user($user) OR (is_user($user) AND ($pm_show == 1))) {
+	$c_mid = base64_decode($p_msg);
+	$result = sql_query("select mid, content, date, who from ".$prefix."_public_messages WHERE mid > '$c_mid' order by date ASC limit 1", $dbi);
+	list($mid, $content, $tdate, $who) = sql_fetch_row($result, $dbi);
+	if ((!isset($c_mid)) OR ($c_mid = $mid)) {
+    	    $public_msg = "<br><table width=\"90%\" border=\"1\" cellspacing=\"2\" cellpadding=\"0\" bgcolor=\"FFFFFF\" align=\"center\"><tr><td>\n";
+    	    $public_msg .= "<table width=\"100%\" border=\"0\" cellspacing=\"1\" cellpadding=\"2\" bgcolor=\"FF0000\"><tr><td>\n";
+    	    $public_msg .= "<font color=\"FFFFFF\" size=\"3\"><b>"._BROADCASTFROM." <a href=\"modules.php?name=Your_Account&amp;op=userinfo&amp;uname=$who\"><font color=\"FFFFFF\" size=\"3\">$who</font></a>: \"$content\"</b>";
+	    $public_msg .= "$t_off";
+	    $public_msg .= "</td></tr></table>";
+    	    $public_msg .= "</td></tr></table>";
+	    $ref_date = $tdate+600;
+	    $actual_date = time();
+	    if ($actual_date >= $ref_date) {
+		$public_msg = "";
+		$numrows = sql_num_rows(sql_query("select * from ".$prefix."_public_messages", $dbi), $dbi);
+		if ($numrows == 1) {
+		    $res = sql_query("delete from ".$prefix."_public_messages", $dbi);
+		    $mid = 0;
+		} else {
+		    $res = sql_query("delete from ".$prefix."_public_messages where mid='$mid'", $dbi);
+		}
+	    }
+	    if ($mid == 0 OR $mid == "") {
+		setcookie("p_msg");
+	    } else {
+    		$mid = base64_encode($mid);
+		setcookie("p_msg",$mid,time()+600);
+	    }
+	}
+    }
+    } else {
+	$public_msg = "";
+    }
+    return($public_msg);
+}
+
+function get_theme() {
+    global $user, $cookie, $Default_Theme;
+    if(is_user($user)) {
+	$user2 = base64_decode($user);
+	$t_cookie = explode(":", $user2);
+	if($t_cookie[9]=="") $t_cookie[9]=$Default_Theme;
+	if(isset($theme)) $t_cookie[9]=$theme;
+	if(!$tfile=@opendir("themes/$t_cookie[9]")) {
+	    $ThemeSel = $Default_Theme;
+	} else {
+	    $ThemeSel = $t_cookie[9];
+	}
+    } else {
+	$ThemeSel = $Default_Theme;
+    }
+    return($ThemeSel);
+}
+
 ?>
\ No newline at end of file
