@@ -32,7 +32,7 @@ define("_LISTOFCONTENT","ioeb ");
 define("_YOURADMINLIST","zO޲z: UO|}񪺺e:");
 define("_COPYRIGHT","Copyright &copy; by");
 define("_COPYRIGHT2","All Right Reserved.");
-define("_CONTENTCATEGORIES","Available Content Categories");
-define("_NONCLASSCONT","Non Categorized Content");
+define("_CONTENTCATEGORIES","iΪؿO");
+define("_NONCLASSCONT","Nؿ");
 
 ?>
\ No newline at end of file
