@@ -40,7 +40,7 @@ define("_DESCRIPTION","Beschrijving");
 define("_AUTHOR","Auteur");
 define("_HOMEPAGE","Homepagina");
 define("_DOWNLOADNOW","Download bestand!");
-define("_RATERESOURCE","Rate Resource");
+define("_RATERESOURCE","Waarderingsbron");
 define("_FILEURL","Bestandlink");
 define("_ADDDOWNLOAD","Download toevoegen");
 define("_DOWNLOADSMAIN","Downloads hoofd");
@@ -49,16 +49,16 @@ define("_DOWNLOADSMAINCAT","Downloads hoofdcategorien");
 define("_ADDADOWNLOAD","Nieuwe download toevoegen");
 define("_DSUBMITONCE","Downloads slechts n maal inzenden.");
 define("_DPOSTPENDING","Alle downloads worden geplaatst, wachtend op goedkeuring.");
-define("_RESSORTED","Resources momenteel gesorteerd");
+define("_RESSORTED","Bronnen momenteel gesorteerd");
 define("_DOWNLOADSNOTUSER1","U bent geen geregistreerde gebruiker of U bent niet ingelogd.");
 define("_DOWNLOADSNOTUSER2","Alleen als u zich geregistreerd heeft, kunt U downloads inzenden.");
 define("_DOWNLOADSNOTUSER3","Registratie duurt niet lang, en is zeker niet moeilijk!");
 define("_DOWNLOADSNOTUSER4","Waarom moet u zich registreren voor toegang tot bepaalde delen van deze website?");
 define("_DOWNLOADSNOTUSER5","Zodat wij de juistheid van deze inzendingen kunnen garanderen;");
-define("_DOWNLOADSNOTUSER6","elke inzending wordt bekeken en vervolgens goed- of afgekeurd.");
+define("_DOWNLOADSNOTUSER6","Elke inzending wordt bekeken en vervolgens goed- of afgekeurd.");
 define("_DOWNLOADSNOTUSER7","Wij streven ernaar om alleen nuttige informatie aan te bieden.");
 define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Aanmelden voor een account</a>");
-define("_DOWNLOADALREADYEXT","FOUT: Deze URL staat al in de database!");
+define("_DOWNLOADALREADYEXT","FOUT: Deze URL staat al in de databank!");
 define("_DOWNLOADNOTITLE","FOUT: U moet een TITEL invoeren voor uw download!");
 define("_DOWNLOADNOURL","FOUT: U moet een URL invoeren voor uw download!");
 define("_DOWNLOADNODESC","FOUT: U moet een BESCHRIJVING invoeren voor uw download!");
@@ -72,7 +72,7 @@ define("_SORTDOWNLOADSBY","Sorteer downloads op");
 define("_DCATNEWTODAY","nieuwe downloads in deze categorie, vandaag toegevoegd");
 define("_DCATLAST3DAYS","nieuwe downloads in deze categorie, in de laatste 3 dagen toegevoegd");
 define("_DCATTHISWEEK","nieuwe downloads in deze categorie, deze week toegevoegd");
-define("_DDATE1","Datum (Oudstee downloads bovenaan)");
+define("_DDATE1","Datum (Oudste downloads bovenaan)");
 define("_DDATE2","Datum (Nieuwste downloads bovenaan)");
 define("_DOWNLOADPROFILE","Download-profiel");
 define("_DOWNLOADRATINGDET","Download waarderingsgegevens");
@@ -92,11 +92,11 @@ define("_ADDITIONALDET","Extra details");
 define("_EDITORREVIEW","Auteurs recentie");
 define("_REPORTBROKEN","Ongeldige link rapporteren");
 define("_AND","en");
-define("_INDB","in onze database");
+define("_INDB","in onze databank");
 define("_INSTRUCTIONS","Instructies");
 define("_USERANDIP","Gebruikersnaam en IP-adres worden geregistreerd, misbruik het systeem a.u.b. niet.");
 define("_LDESCRIPTION","Beschrijving (max. 255 karakters):");
-define("_CHECKFORIT","U heeft geen e-mailadres opgegeven. U zult daarom geen plaatsingsbericht ontvangen.");
+define("_CHECKFORIT","U heeft geen E-mailadres opgegeven. U zult daarom geen plaatsingsbericht ontvangen.");
 define("_LASTWEEK","Laatste week");
 define("_LAST30DAYS","Laatste 30 dagen");
 define("_1WEEK","1 week");
@@ -122,8 +122,8 @@ define("_POPULARITY1","Populariteit (minste hits bovenaan)");
 define("_POPULARITY2","Populariteit (meeste hits bovenaan)");
 define("_TITLEAZ","Titel (A t/m Z)");
 define("_TITLEZA","Titel (Z t/m A)");
-define("_RATING1","Rating (Laagste score bovenaan)");
-define("_RATING2","Rating (Hoogste score bovenaan)");
+define("_RATING1","Waardering (Laagste score bovenaan)");
+define("_RATING2","Waardering (Hoogste score bovenaan)");
 define("_SEARCHRESULTS4","Zoek resultaten voor");
 define("_USUBCATEGORIES","Subcategorien");
 define("_TRY2SEARCH","Probeer te zoeken");
@@ -159,7 +159,7 @@ define("_TEXTLINK","Tekstlink");
 define("_PROMOTE02","Een manier om te linken naar het waarderingsformulier is met een eenvoudige tekstlink:");
 define("_HTMLCODE1","De HTML-code die u gebruikt in dit geval is als volgt:");
 define("_THENUMBER","Het cijfer");
-define("_IDREFER","in de HTML-broncode refereert naar het ID-nummer in de $sitename database. Zorg er dus voor dat dit nummer aanwezig is.");
+define("_IDREFER","in de HTML-broncode refereert naar het ID-nummer in de $sitename databank. Zorg er dus voor dat dit nummer aanwezig is.");
 define("_BUTTONLINK","Knop-link");
 define("_PROMOTE03","Iets meer dan een gewonen tekstlink is de knop-link:");
 define("_RATEIT","Stem op deze site!");
@@ -170,14 +170,14 @@ define("_VOTE4THISSITE","Stem op deze site!");
 define("_HTMLCODE3","Dit formulier laat gebruikers een waardering geven van uw website, rechtstreeks vanaf uw site. De waardering wordt dan hier verwerkt. Knip en plak de volgende broncode in uw webpagina, voor een formulier als het bovenstaande:");
 define("_PROMOTE05","Bedankt, en veel succes met uw website!");
 define("_STAFF","Staf");
-define("_THANKSBROKEN","Bedankt voor uw hulp bij het up to date houden deze map.");
+define("_THANKSBROKEN","Bedankt voor uw hulp bij het up to date houden van deze map.");
 define("_SECURITYBROKEN","Uw gebruikersnaam en IP-adres worden tijdelijk genoteerd.");
 define("_THANKSFORINFO","Bedankt voor de informatie.");
 define("_LOOKTOREQUEST","Wij zullen uw verzoek zo spoedig mogelijk in behandeling nemen.");
 define("_SENDREQUEST","Verzend verzoek");
-define("_THANKSTOTAKETIME","Bedankt voor het waarderen van een site hier bij");
+define("_THANKSTOTAKETIME","Bedankt voor uw tijd");
 define("_RETURNTO","Terug naar");
-define("_RATENOTE1","U kunt maar een maal per dag op hetzelfde onderwerp stemmen.");
+define("_RATENOTE1","U kunt maar n maal per dag op hetzelfde onderwerp stemmen.");
 define("_RATENOTE2","De waardering loopt van 1 t/m 10, waarbij 1 staat voor zwak en 10 voor uitstekend.");
 define("_RATENOTE3","Wees objectief bij het stemmen: als iedereen een 1 of een 10 geeft, dan zijn de waarderingen niet nuttig.");
 define("_RATENOTE5","Stem niet op uw eigen website of die van een concurrent.");
@@ -195,4 +195,4 @@ define("_COMPLETEVOTE5","Geen waardering geselecteerd - er is geen stem bijgetel
 define("_COMPLETEVOTE6","Er is slechts 1 stem per IP-addres toegestaan elke $outsidewaitdays dag(en).");
 define("_LINKSDATESTRING","%d-%b-%Y");
 
-?>
\ No newline at end of file
+?>
