@@ -16,10 +16,13 @@
 /* so your entry will look like: This is \"double quoted\" text.          */
 /* And, if you use HTML code, please double check it.                     */
 /**************************************************************************/
+/*Translated to Brazilian by: Luiz Gustavo Aleagi Nunes - tatau           */
+/*For any comments/suggestions: aleagi@terra.com.br			        */
+/**************************************************************************/
 
 define("_CATEGORY","Categoria");
 define("_CATEGORIES","Categorias");
-define("_FAQ2","FAQ (Perguntas Mais Freqentes)");
+define("_FAQ2","FAQ (Perguntas frequentes)");
 define("_BACKTOTOP","Voltar ao TOP");
 define("_BACKTOFAQINDEX","Voltar ao ndice do FAQ");
 define("_MAIN","ndice");
