@@ -55,7 +55,7 @@ define("_READREST","Komentario guztia irakurri...");
 define("_REPLY","Honi erantzun");
 define("_REPLYMAIN","Komentarioa bidali");
 define("_NOSUBJECT","Gairik gabe");
-define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"user.php\">erregstratu</a> zaitez");
+define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"modules.php?name=Your_Account\">erregstratu</a> zaitez");
 define("_PARENT","Aurrekoa");
 define("_ROOT","Erroa/Lehena");
 
@@ -125,5 +125,6 @@ define("_GOTONEWSINDEX","Go to News Index");
 define("_SELECTNEWTOPIC","Select a New Topic");
 define("_GOTOHOME","Go to Home");
 define("_SEARCHONTOPIC","Search on This Topic");
+define("_SEARCHDIS","Search Discussion");
 
 ?>
\ No newline at end of file
