@@ -45,8 +45,8 @@ define("_BBCODE"," BB");
 define("_WROTE","");
 define("_OPTIONS","");
 define("_HTMLDISSABLE","     ");
-define("_BBCODEDISSABLE"," <a href=\"bbcode_ref.php\" target=\"_blank\"><i> BB</i></a>   ");
-define("_SMILEDISSABLE"," <a href=\"bb_smilies.php\" target=\"_blank\"><i> </i></a>   ");
+define("_BBCODEDISSABLE"," <i> BB</i>   ");
+define("_SMILEDISSABLE"," <i> </i>   ");
 define("_CANCELREPLY"," ");
 define("_CANCELSEND"," ");
 define("_CLEAR","");
@@ -57,19 +57,24 @@ define("_MSGPOSTED","  .");
 define("_RETURNTOPMSG","    .");
 define("_MSGDELETED","  .");
 define("_BBGO","go");
-define("_BBNEWPMSG","New Messages");
-define("_BBNONEWPMSG","No New Messages");
-define("_BBTOTALPMSG","Total Messages");
-define("_BBEMPTYPMSG","You don't have any Messages");
-define("_BBLOGIN","Login to check your private message");
-define("_BBPMSG","Private Message");
-define("_BBINBOX","Inbox");
-define("_BBSELECTFORUM","Select a Forum");
-define("_BBNOFORUM","No More Forum");
-define("_BBBANNED","Banned");
-define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
-define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
-define("_PRIVMSGERROR","Private Message Error!");
-define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")
+define("_BBNEWPMSG"," ");
+define("_BBNONEWPMSG","   ");
+define("_BBTOTALPMSG"," ");
+define("_BBEMPTYPMSG","   ");
+define("_BBLOGIN","     ");
+define("_BBPMSG"," ");
+define("_BBINBOX"," ");
+define("_BBSELECTFORUM"," ");
+define("_BBNOFORUM"," ");
+define("_BBBANNED","");
+define("_CLICKSMILEBUTTONS","     :");
+define("_CLICKCODEBUTTONS","         :");
+define("_PRIVMSGERROR","   !");
+define("_USERDOESNTEXIST","    ")
+define("_DELETESELECTED"," ");
+define("_SENDNEWMSG","  ");
+define("_REPLY"," ");
+define("_NOSUBJECT","   .");
+define("_NOMESSAGE","  .   !");
 
 ?>
\ No newline at end of file
