@@ -6,7 +6,7 @@
 /*                                                                        */
 /* This is the language module with all the system messages               */
 /*                                                                        */
-/* If you made a translation, please go to the site and send to me        */
+/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
 /* the translated file. Please keep the original text order by modules,   */
 /* and just one message per line, also double check your translation!     */
 /*                                                                        */
@@ -24,12 +24,12 @@ define("_FFRIENDNAME","͹س:");
 define("_FFRIENDEMAIL","͹س:");
 define("_HELLO","ʴ");
 define("_YOURFRIEND","س");
-define("_RECOMMEND","й ͡");
-define("_INTSITE","Web ʹ:");
-define("_OURSITE","Ԩó site ͧ");
-define("_INTSENT","ʹеͧ觶֧س.");
-define("_FSITENAME"," Site :");
-define("_FSITEURL","Site URL:");
+define("_RECOMMEND","йӺ͡");
+define("_INTSITE","纷ʹ:");
+define("_OURSITE","Ԩó红ͧ");
+define("_INTSENT","ʹеͧ觶֧س");
+define("_FSITENAME"," :");
+define("_FSITEURL"," URL:");
 define("_FREFERENCE","Ţͧ䫵١ѧ");
 define("_THANKSREC","͢ͺسй!");
 
