@@ -79,7 +79,7 @@ define("_TOTALREVIEWS","  .");
 define("_RETURN2MAIN","   ");
 define("_REVIEWCOMMENT"," :");
 define("_YOURNICK"," :");
-define("_RCREATEACCOUNT","<a href=user.php></a> ");
+define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account></a> ");
 define("_YOURCOMMENT"," :");
 define("_MYSCORE"," :");
 define("_REVIEWMOD","Review Modification");
