@@ -21,7 +21,7 @@ $module_name = basename(dirname(__FILE__));
 get_lang($module_name);
 
 function listsections() {
-    global $sitename, $prefix, $dbi;
+    global $sitename, $prefix, $dbi, $module_name;
     include ('header.php');
     $result = sql_query("select secid, secname, image from ".$prefix."_sections order by secname", $dbi);
     OpenTable();
@@ -35,7 +35,7 @@ function listsections() {
         echo "<tr>";
         $count = 0;
         }
-        echo "<td><a href=\"modules.php?name=Sections&op=listarticles&secid=$secid\"><img src=\"images/sections/$image\" border=\"0\" Alt=\"$secname\"></a>";
+        echo "<td><a href=\"modules.php?name=$module_name&op=listarticles&secid=$secid\"><img src=\"images/sections/$image\" border=\"0\" Alt=\"$secname\"></a>";
         $count++;
         if ($count==2) {
         echo "</tr>";
@@ -48,7 +48,7 @@ function listsections() {
 }
 
 function listarticles($secid) {
-    global $prefix, $multilingual, $currentlang, $dbi;
+    global $prefix, $multilingual, $currentlang, $dbi, $module_name;
     if ($multilingual == 1) {
     $querylang = "AND slanguage='$currentlang'";
     } else {
@@ -68,20 +68,20 @@ function listarticles($secid) {
     while (list($artid, $secid, $title, $content, $counter) = sql_fetch_row($result, $dbi)) {
         echo "
         <tr><td align=\"left\" nowrap><font class=\"content\">
-        <li><a href=\"modules.php?name=Sections&op=viewarticle&artid=$artid\">$title</a> ($counter "._READS.")
-        <a href=\"modules.php?name=Sections&op=printpage&artid=$artid\"><img src=\"images/print.gif\" border=\"0\" Alt=\""._PRINTER."\" width=\"15\" height=\"11\"></a>
+        <li><a href=\"modules.php?name=$module_name&op=viewarticle&artid=$artid\">$title</a> ($counter "._READS.")
+        <a href=\"modules.php?name=$module_name&op=printpage&artid=$artid\"><img src=\"images/print.gif\" border=\"0\" Alt=\""._PRINTER."\" width=\"15\" height=\"11\"></a>
         </td></tr>
         ";
     }
     echo "</table>
     <br><br><br><center>
-    [ <a href=\"modules.php?name=Sections\">"._SECRETURN."</a> ]</center>";
+    [ <a href=\"modules.php?name=$module_name\">"._SECRETURN."</a> ]</center>";
     CloseTable();
     include ('footer.php');
 }
 
 function viewarticle($artid, $page) {
-    global $prefix, $dbi;
+    global $prefix, $dbi, $module_name;
     include("header.php");
     if (($page == 1) OR ($page == "")) {
 	sql_query("update ".$prefix."_seccont set counter=counter+1 where artid='$artid'", $dbi);
@@ -108,7 +108,7 @@ function viewarticle($artid, $page) {
     }
     echo "($words "._TOTALWORDS.")<br>"
 	."($counter "._READS.") &nbsp;&nbsp;"
-	."<a href=\"modules.php?name=Sections&op=printpage&amp;artid=$artid\"><img src=\"images/print.gif\" border=\"0\" Alt=\""._PRINTER."\" width=\"15\" height=\"11\"></a>"
+	."<a href=\"modules.php?name=$module_name&op=printpage&amp;artid=$artid\"><img src=\"images/print.gif\" border=\"0\" Alt=\""._PRINTER."\" width=\"15\" height=\"11\"></a>"
 	."</font><br><br><br><br>";
     echo "$contentpages[$arrayelement]";
     if($page >= $pageno) {
@@ -118,27 +118,27 @@ function viewarticle($artid, $page) {
 	if ($page != 1) {
 	    $next_page .= "<img src=\"images/blackpixel.gif\" width=\"10\" height=\"2\" border=\"0\" alt=\"\"> &nbsp;&nbsp; ";
 	}
-	$next_page .= "<a href=\"modules.php?name=Sections&op=viewarticle&amp;artid=$artid&amp;page=$next_pagenumber\">"._NEXT." ($next_pagenumber/$pageno)</a> <a href=\"modules.php?name=Sections&op=viewarticle&artid=$artid&page=$next_pagenumber\"><img src=\"images/download/right.gif\" border=\"0\" alt=\""._NEXT."\"></a>";
+	$next_page .= "<a href=\"modules.php?name=$module_name&op=viewarticle&amp;artid=$artid&amp;page=$next_pagenumber\">"._NEXT." ($next_pagenumber/$pageno)</a> <a href=\"modules.php?name=$module_name&op=viewarticle&artid=$artid&page=$next_pagenumber\"><img src=\"images/download/right.gif\" border=\"0\" alt=\""._NEXT."\"></a>";
     }
 
     if($page <= 1) {
 	$previous_page = "";
     } else {
 	$previous_pagenumber = $page - 1;
-	$previous_page = "<a href=\"modules.php?name=Sections&op=viewarticle&amp;artid=$artid&amp;page=$previous_pagenumber\"><img src=\"images/download/left.gif\" border=\"0\" alt=\""._PREVIOUS."\"></a> <a href=\"modules.php?name=Sections&op=viewarticle&artid=$artid&page=$previous_pagenumber\">"._PREVIOUS." ($previous_pagenumber/$pageno)</a>";
+	$previous_page = "<a href=\"modules.php?name=$module_name&op=viewarticle&amp;artid=$artid&amp;page=$previous_pagenumber\"><img src=\"images/download/left.gif\" border=\"0\" alt=\""._PREVIOUS."\"></a> <a href=\"modules.php?name=$module_name&op=viewarticle&artid=$artid&page=$previous_pagenumber\">"._PREVIOUS." ($previous_pagenumber/$pageno)</a>";
     }
     echo "</td></tr>"
 	."<tr><td align=\"center\">"
 	."$previous_page &nbsp;&nbsp; $next_page<br><br>"
-	."[ <a href=\"modules.php?name=Sections&op=listarticles&amp;secid=$secid\">"._BACKTO." $secname</a> | "
-	."<a href=\"modules.php?name=Sections\">"._SECINDEX."</a> ]";
+	."[ <a href=\"modules.php?name=$module_name&op=listarticles&amp;secid=$secid\">"._BACKTO." $secname</a> | "
+	."<a href=\"modules.php?name=$module_name\">"._SECINDEX."</a> ]";
     CloseTable();
     echo "</center>";
     include ('footer.php');
 }
 
 function PrintSecPage($artid) {
-    global $site_logo, $nukeurl, $sitename, $datetime, $prefix, $dbi;
+    global $site_logo, $nukeurl, $sitename, $datetime, $prefix, $dbi, $module_name;
     $result = sql_query("select title, content from ".$prefix."_seccont where artid=$artid", $dbi);
     list($title, $content) = sql_fetch_row($result, $dbi);
     echo "
@@ -160,7 +160,7 @@ function PrintSecPage($artid) {
     "._COMESFROM." $sitename<br>
     <a href=\"$nukeurl\">$nukeurl</a><br><br>
     "._THEURL."<br>
-    <a href=\"$nukeurl/modules.php?name=Sections&op=viewarticle&amp;artid=$artid\">$nukeurl/modules.php?name=Sections&op=viewarticle&amp;artid=$artid</a></font></center>
+    <a href=\"$nukeurl/modules.php?name=$module_name&op=viewarticle&amp;artid=$artid\">$nukeurl/modules.php?name=$module_name&op=viewarticle&amp;artid=$artid</a></font></center>
     </td></tr></table>
     </body>
     </html>
