@@ -37,7 +37,7 @@ define("_READREST","Lesa afganginn af athugasemdinni...");
 define("_REPLY","Svara essu");
 define("_REPLYMAIN","Gera athugasemd");
 define("_NOSUBJECT","Engin fyrirsgn");
-define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account\">skr ig hr</a>");
+define("_NOANONCOMMENTS","Aeins skrir notendur mega senda inn athugasemdir.   getur <a href=\"modules.php?name=Your_Account&amp;op=new_user\">skr ig hr</a>");
 define("_PARENT","Efst  r");
 define("_ROOT","Efst");
 define("_UCOMMENT","Athugasemd");
@@ -54,9 +54,6 @@ define("_NOTRIGHT","Eitthva fr forgrum vi a flytja breytu  etta fall. essi skila
 define("_DIRECTCOM","Bein athugasemd vi knnun...");
 define("_SENDAMSG","Senda skilabo");
 define("_PASTSURVEYS","Fyrri kannanir");
-
-
-
 define("_LVOTES","atkvi");
 define("_TOTALVOTES","Fjldi atkva:");
 define("_VOTING","Kjrklefinn");
@@ -68,5 +65,7 @@ define("_REFRESH","Endurhlaa");
 define("_SURVEYS","Skoanakannanir");
 define("_ATTACHEDTOARTICLE","- Attached to article:");
 define("_SURVEYSATTACHED","Surveys Attached to Articles");
+define("_LAST5POLLS", "Last 5 Surveys at");
+define("_MOREPOLLS", "...more polls");
 
 ?>
\ No newline at end of file
