@@ -16,8 +16,12 @@
 /* so your entry will look like: This is \"double quoted\" text.          */
 /* And, if you use HTML code, please double check it.                     */
 /**************************************************************************/
+/*Translated to Brazilian by: Luiz Gustavo Aleagi Nunes - tatau           */
+/*For any comments/suggestions: aleagi@terra.com.br			        */
+/**************************************************************************/
 
-define("_ACTIVETOPICS","Tpicos Ativos Atualmente");
-define("_CLICK2LIST","Click para listar todos os artigos deste tpico");
+
+define("_ACTIVETOPICS","Tpicos ativos atualmente");
+define("_CLICK2LIST","Clique para listar todos os Artigos deste Tpico");
 
 ?>
\ No newline at end of file
