@@ -20,10 +20,10 @@ if (!eregi("modules.php", $PHP_SELF)) {
     die ("You can't access this file directly...");
 }
 $index = 1;
-$pagetitle = "- "._WEBLINKS."";
 require_once("mainfile.php");
 $module_name = basename(dirname(__FILE__));
 get_lang($module_name);
+$pagetitle = "- "._WEBLINKS."";
 require_once("modules/Web_Links/l_config.php");
 
 function getparent($parentid,$title) {
@@ -41,7 +41,7 @@ function getparentlink($parentid,$title) {
     global $prefix, $dbi;
     $result=sql_query("select cid, title, parentid from ".$prefix."_links_categories where cid=$parentid", $dbi);
     list($cid, $ptitle, $pparentid) = sql_fetch_row($result, $dbi);
-    if ($ptitle!="") $title="<a href=modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&cid=$cid>$ptitle</a>/".$title;
+    if ($ptitle!="") $title="<a href=modules.php?name=Web_Links&l_op=viewlink&cid=$cid>$ptitle</a>/".$title;
     if ($pparentid!=0) {
     	$title=getparentlink($pparentid,$title);
     }
@@ -49,26 +49,27 @@ function getparentlink($parentid,$title) {
 }
 
 function menu($mainlink) {
+    global $module_name;
     OpenTable();
-    echo "<br><center><a href=\"modules.php?name=Web_Links\"><img src=\"images/links/web.gif\" border=\"0\" alt=\"\"></a><br><br>";
-    echo "<form action=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$query\" method=\"post\">"
+    echo "<br><center><a href=\"modules.php?name=Web_Links\"><img src=\"modules/$module_name/images/web.gif\" border=\"0\" alt=\"\"></a><br><br>";
+    echo "<form action=\"modules.php?name=Web_Links&l_op=search&amp;query=$query\" method=\"post\">"
 	."<font class=\"content\"><input type=\"text\" size=\"25\" name=\"query\"> <input type=\"submit\" value=\""._SEARCH."\"></font>"
 	."</form>";
     echo "<font class=\"content\">[ ";
     if ($mainlink>0) {
 	echo "<a href=\"modules.php?name=Web_Links\">"._LINKSMAIN."</a> | ";
     }
-    echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=AddLink\">"._ADDLINK."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=NewLinks\">"._NEW."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular\">"._POPULAR."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated\">"._TOPRATED."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=RandomLink\">"._RANDOM."</a> ]"
+    echo "<a href=\"modules.php?name=Web_Links&l_op=AddLink\">"._ADDLINK."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=NewLinks\">"._NEW."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=MostPopular\">"._POPULAR."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=TopRated\">"._TOPRATED."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=RandomLink\">"._RANDOM."</a> ]"
 	."</font></center>";
     CloseTable();
 }
 
 function SearchForm() {
-    echo "<form action=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&query=$query\" method=\"post\">"
+    echo "<form action=\"modules.php?name=Web_Links&l_op=search&query=$query\" method=\"post\">"
 	."<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" align=\"center\">"
 	."<tr><td><font class=\"content\"><input type=\"text\" size=\"25\" name=\"query\"> <input type=\"submit\" value=\""._SEARCH."\"></td></tr>"
 	."</table>"
@@ -77,11 +78,11 @@ function SearchForm() {
 
 function linkinfomenu($lid, $ttitle) {
     echo "<br><font class=\"content\">[ "
-	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$ttitle\">"._LINKCOMMENTS."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$ttitle\">"._ADDITIONALDET."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkeditorial&amp;lid=$lid&amp;ttitle=$ttitle\">"._EDITORREVIEW."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=modifylinkrequest&amp;lid=$lid\">"._MODIFY."</a>"
-	." | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a> ]</font>";
+	."<a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$ttitle\">"._LINKCOMMENTS."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$ttitle\">"._ADDITIONALDET."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=viewlinkeditorial&amp;lid=$lid&amp;ttitle=$ttitle\">"._EDITORREVIEW."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=modifylinkrequest&amp;lid=$lid\">"._MODIFY."</a>"
+	." | <a href=\"modules.php?name=Web_Links&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a> ]</font>";
 }
 
 function index() {
@@ -96,7 +97,7 @@ function index() {
     $result = sql_query("select cid, title, cdescription from ".$prefix."_links_categories where parentid=0 order by title", $dbi);
     $count = 0;
     while(list($cid, $title, $cdescription) = sql_fetch_row($result, $dbi)) {
-	echo "<td><font class=\"option\"><strong><big>&middot;</big></strong> <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid\"><b>$title</b></a></font>";
+	echo "<td><font class=\"option\"><strong><big>&middot;</big></strong> <a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid\"><b>$title</b></a></font>";
 	categorynewlinkgraphic($cid);
 	if ($cdescription) {
 	    echo "<br><font class=\"content\">$cdescription</font><br>";
@@ -109,7 +110,7 @@ function index() {
     	    if ($space>0) {
 		echo ",&nbsp;";
 	    }
-	    echo "<font class=\"content\"><a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid\">$stitle</a></font>";
+	    echo "<font class=\"content\"><a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid\">$stitle</a></font>";
 	    $space++;
 	}
 	if ($count<1) {
@@ -150,7 +151,7 @@ function AddLink() {
 	    ."<strong><big>&middot;</big></strong> "._SUBMITONCE."<br>"
 	    ."<strong><big>&middot;</big></strong> "._POSTPENDING."<br>"
 	    ."<strong><big>&middot;</big></strong> "._USERANDIP."<br>"
-    	    ."<form method=\"post\" action=\"modules.php?op=modload&name=Web_Links&file=index&l_op=Add\">"
+    	    ."<form method=\"post\" action=\"modules.php?name=Web_Links&l_op=Add\">"
     	    .""._PAGETITLE.": <input type=\"text\" name=\"title\" size=\"50\" maxlength=\"100\"><br>"
     	    .""._PAGEURL.": <input type=\"text\" name=\"url\" size=\"50\" maxlength=\"100\" value=\"http://\"><br>";
     	echo ""._CATEGORY.": <select name=\"cat\">";
@@ -287,7 +288,7 @@ function NewLinks($newlinkshowdays) {
         $counter++;
     }
     echo "<center><b>"._TOTALNEWLINKS.":</b> "._LASTWEEK." - $allweeklinks \ "._LAST30DAYS." - $allmonthlinks<br>"
-	.""._SHOW.": <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=NewLinks&amp;newlinkshowdays=7\">"._1WEEK."</a> - <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=NewLinks&amp;newlinkshowdays=14\">"._2WEEKS."</a> - <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=NewLinks&amp;newlinkshowdays=30\">"._30DAYS."</a>"
+	.""._SHOW.": <a href=\"modules.php?name=Web_Links&l_op=NewLinks&amp;newlinkshowdays=7\">"._1WEEK."</a> - <a href=\"modules.php?name=Web_Links&l_op=NewLinks&amp;newlinkshowdays=14\">"._2WEEKS."</a> - <a href=\"modules.php?name=Web_Links&l_op=NewLinks&amp;newlinkshowdays=30\">"._30DAYS."</a>"
 	."</center><br>";
     /* List Last VARIABLE Days of Links */
     if (!isset($newlinkshowdays)) {
@@ -305,7 +306,7 @@ function NewLinks($newlinkshowdays) {
 	$totallinks = sql_num_rows($result, $dbi);
 	$counter++;
 	$allweeklinks = $allweeklinks + $totallinks;
-	echo "<strong><big>&middot;</big></strong> <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=NewLinksDate&amp;selectdate=$newlinkdayRaw\">$newlinkView</a>&nbsp($totallinks)<br>";
+	echo "<strong><big>&middot;</big></strong> <a href=\"modules.php?name=Web_Links&l_op=NewLinksDate&amp;selectdate=$newlinkdayRaw\">$newlinkView</a>&nbsp($totallinks)<br>";
     }
     $counter = 0;
     $allmonthlinks = 0;
@@ -336,7 +337,7 @@ function NewLinksDate($selectdate) {
     while(list($lid, $cid, $sid, $title, $description, $time, $hits, $linkratingsummary, $totalvotes, $totalcomments)=sql_fetch_row($result, $dbi)) {
 	$linkratingsummary = number_format($linkratingsummary, $mainvotedecimal);
 	$title = stripslashes($title); $description = stripslashes($description);
-        echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
+        echo "<a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
 	newlinkgraphic($datetime, $time);
 	popgraphic($hits);
 	echo "<br>"._DESCRIPTION.": $description<br>";
@@ -360,13 +361,13 @@ function NewLinksDate($selectdate) {
 	if ($radminsuper==1 || $radminlink==1) {
 		echo "<a href=\"admin.php?op=LinksModLink&amp;lid=$lid\">"._EDIT."</a> | ";
 	}
-		echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
-        echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
+		echo "<a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
+        echo " | <a href=\"modules.php?name=Web_Links&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
 	if ($totalvotes != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
 	}
         if ($totalcomments != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
 	}
 	detecteditorial($lid, $transfertitle);
 	echo "<br>";
@@ -410,19 +411,19 @@ function TopRated($ratenum, $ratetype) {
     }
     echo "</td></tr>"
 	."<tr><td><center>"._NOTE." $linkvotemin "._TVOTESREQ."<br>"
-	.""._SHOWTOP.":  [ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=10&amp;ratetype=num\">10</a> - "
-	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=25&amp;ratetype=num\">25</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=50&amp;ratetype=num\">50</a> | "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=1&amp;ratetype=percent\">1%</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=5&amp;ratetype=percent\">5%</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=TopRated&amp;ratenum=10&amp;ratetype=percent\">10%</a> ]</center><br><br></td></tr>";
+	.""._SHOWTOP.":  [ <a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=10&amp;ratetype=num\">10</a> - "
+	."<a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=25&amp;ratetype=num\">25</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=50&amp;ratetype=num\">50</a> | "
+    	."<a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=1&amp;ratetype=percent\">1%</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=5&amp;ratetype=percent\">5%</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=TopRated&amp;ratenum=10&amp;ratetype=percent\">10%</a> ]</center><br><br></td></tr>";
     $result=sql_query("select lid, cid, sid, title, description, date, hits, linkratingsummary, totalvotes, totalcomments from ".$prefix."_links_links where linkratingsummary != 0 and totalvotes >= $linkvotemin order by linkratingsummary DESC limit 0,$toplinks", $dbi);
     echo "<tr><td>";
     while(list($lid, $cid, $sid, $title, $description, $time, $hits, $linkratingsummary, $totalvotes, $totalcomments)=sql_fetch_row($result, $dbi)) {
 	$linkratingsummary = number_format($linkratingsummary, $mainvotedecimal);
 	$title = stripslashes($title);
 	$description = stripslashes($description);
-        echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
+        echo "<a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
 	newlinkgraphic($datetime, $time);
 	popgraphic($hits);
 	echo "<br>";
@@ -442,13 +443,13 @@ function TopRated($ratenum, $ratetype) {
 	if ($linkratingsummary!="0" || $linkratingsummary!="0.0") {
 	    echo " "._RATING.": <b> $linkratingsummary </b> ($totalvotes $votestring)";
 	}
-	echo "<br><a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
-	echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
+	echo "<br><a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
+	echo " | <a href=\"modules.php?name=Web_Links&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
 	if ($totalvotes != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
 	}
 	if ($totalcomments != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
 	}
 	detecteditorial($lid, $transfertitle);
 	echo "<br>";
@@ -496,19 +497,19 @@ global $prefix,$admin,$dbi;
     } else {
 	echo "<center><font class=\"option\"><b>"._MOSTPOPULAR." $mostpoplinks</b></font></center>";
     }
-    echo "<tr><td><center>"._SHOWTOP.": [ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=10&amp;ratetype=num\">10</a> - "
-	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=25&amp;ratetype=num\">25</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=50&amp;ratetype=num\">50</a> | "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=1&amp;ratetype=percent\">1%</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=5&amp;ratetype=percent\">5%</a> - "
-    	."<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=MostPopular&amp;ratenum=10&amp;ratetype=percent\">10%</a> ]</center><br><br></td></tr>";
+    echo "<tr><td><center>"._SHOWTOP.": [ <a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=10&amp;ratetype=num\">10</a> - "
+	."<a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=25&amp;ratetype=num\">25</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=50&amp;ratetype=num\">50</a> | "
+    	."<a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=1&amp;ratetype=percent\">1%</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=5&amp;ratetype=percent\">5%</a> - "
+    	."<a href=\"modules.php?name=Web_Links&l_op=MostPopular&amp;ratenum=10&amp;ratetype=percent\">10%</a> ]</center><br><br></td></tr>";
     $result=sql_query("select lid, cid, sid, title, description, date, hits, linkratingsummary, totalvotes, totalcomments from ".$prefix."_links_links order by hits DESC limit 0,$mostpoplinks", $dbi);
     echo "<tr><td>";
     while(list($lid, $cid, $sid, $title, $description, $time, $hits, $linkratingsummary, $totalvotes, $totalcomments)=sql_fetch_row($result, $dbi)) {
 	$linkratingsummary = number_format($linkratingsummary, $mainvotedecimal);
 	$title = stripslashes($title);
 	$description = stripslashes($description);
-        echo "<font class=\"content\"><a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
+        echo "<font class=\"content\"><a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
 	newlinkgraphic($datetime, $time);
 	popgraphic($hits);
 	echo "<br>";
@@ -532,13 +533,13 @@ global $prefix,$admin,$dbi;
     if ($radminsuper==1 || $radminlink==1) {
     	echo "<a href=\"admin.php?op=LinksModLink&amp;lid=$lid\">"._EDIT."</a> | ";
     }
-	echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
-	echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
+	echo "<a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
+	echo " | <a href=\"modules.php?name=Web_Links&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
 	if ($totalvotes != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
 	}
 	if ($totalcomments != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
 	}
 	detecteditorial($lid, $transfertitle);
 	echo "<br>";
@@ -604,7 +605,7 @@ function viewlink($cid, $min, $orderby, $show) {
     $result2 = sql_query("select cid, title, cdescription from ".$prefix."_links_categories where parentid=$cid order by title", $dbi);
     $count = 0;
     while(list($cid2, $title2, $cdescription2) = sql_fetch_row($result2, $dbi)) {
-	echo "<td><font class=\"option\"><strong><big></big></strong> <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid2\"><b>$title2</b></a></font>";
+	echo "<td><font class=\"option\"><strong><big></big></strong> <a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid2\"><b>$title2</b></a></font>";
 	categorynewlinkgraphic($cid2);
 	if ($description) {
 	    echo "<font class=\"content\">$cdescription2</font><br>";
@@ -617,7 +618,7 @@ function viewlink($cid, $min, $orderby, $show) {
     	    if ($space>0) {
 		echo ",&nbsp;";
 	    }
-	    echo "<font class=\"content\"><a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid3\">$title3</a></font>";
+	    echo "<font class=\"content\"><a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid3\">$title3</a></font>";
 	    $space++;
 	}
 	if ($count<1) {
@@ -640,10 +641,10 @@ function viewlink($cid, $min, $orderby, $show) {
     echo "<hr noshade size=\"1\">";
     $orderbyTrans = convertorderbytrans($orderby);
     echo "<center><font class=\"content\">"._SORTLINKSBY.": "
-        .""._TITLE." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=titleA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=titleD\">D</a>) "
-        .""._DATE." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=dateA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=dateD\">D</a>) "
-        .""._RATING." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=ratingA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=ratingD\">D</a>) "
-        .""._POPULARITY." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=hitsA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;orderby=hitsD\">D</a>)"
+        .""._TITLE." (<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=titleA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=titleD\">D</a>) "
+        .""._DATE." (<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=dateA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=dateD\">D</a>) "
+        .""._RATING." (<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=ratingA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=ratingD\">D</a>) "
+        .""._POPULARITY." (<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=hitsA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;orderby=hitsD\">D</a>)"
 	."<br><b>"._SITESSORTED.": $orderbyTrans</b></font></center><br><br>";
     $result=sql_query("select lid, title, description, date, hits, linkratingsummary, totalvotes, totalcomments from ".$prefix."_links_links where cid=$cid order by $orderby limit $min,$perpage", $dbi);
     $fullcountresult=sql_query("select lid, title, description, date, hits, linkratingsummary, totalvotes, totalcomments from ".$prefix."_links_links where cid=$cid", $dbi);
@@ -654,7 +655,7 @@ function viewlink($cid, $min, $orderby, $show) {
 	$linkratingsummary = number_format($linkratingsummary, $mainvotedecimal);
 	$title = stripslashes($title);
 	$description = stripslashes($description);
-        echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"new\"><b>$title</b></a>";
+        echo "<a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"new\"><b>$title</b></a>";
 	newlinkgraphic($datetime, $time);
 	popgraphic($hits);
 	/* INSERT code for *editor review* here */
@@ -679,13 +680,13 @@ function viewlink($cid, $min, $orderby, $show) {
     	if ($radminsuper==1 || $radminlink==1) {
     		echo "<a href=\"admin.php?op=LinksModLink&amp;lid=$lid\">"._EDIT."</a> | ";
     	}
-		echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
-        echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
+		echo "<a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
+        echo " | <a href=\"modules.php?name=Web_Links&l_op=brokenlink&amp;lid=$lid\">"._REPORTBROKEN."</a>";
 	if ($totalvotes != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
 	}
         if ($totalcomments != 0) {
-	    echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
+	    echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle\">"._SCOMMENTS." ($totalcomments)</a>";
 	}
         detecteditorial($lid, $transfertitle);
 	echo "<br><br>";
@@ -710,7 +711,7 @@ function viewlink($cid, $min, $orderby, $show) {
       	echo ""._SELECTPAGE.": ";
      	$prev=$min-$perpage;
      	if ($prev>=0) {
-    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;min=$prev&amp;orderby=$orderby&amp;show=$show\">";
+    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;min=$prev&amp;orderby=$orderby&amp;show=$show\">";
     	    echo " &lt;&lt; "._PREVIOUS."</a> ]</b> ";
   	}
     	$counter = 1;
@@ -721,13 +722,13 @@ function viewlink($cid, $min, $orderby, $show) {
       	    if ($counter == $currentpage) {
 		echo "<b>$counter</b>&nbsp";
 	    } else {
-		echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;min=$mintemp&amp;orderby=$orderby&amp;show=$show\">$counter</a> ";
+		echo "<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;min=$mintemp&amp;orderby=$orderby&amp;show=$show\">$counter</a> ";
 	    }
        	    $counter++;
        	}
      	$next=$min+$perpage;
      	if ($x>=$perpage) {
-    		echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid&amp;min=$max&amp;orderby=$orderby&amp;show=$show\">";
+    		echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid&amp;min=$max&amp;orderby=$orderby&amp;show=$show\">";
     		echo " "._NEXT." &gt;&gt;</a> ]</b> ";
      	}
     }
@@ -737,6 +738,7 @@ function viewlink($cid, $min, $orderby, $show) {
 }
 
 function newlinkgraphic($datetime, $time) {
+    global $module_name;
     echo "&nbsp;";
     setlocale ("LC_TIME", "$locale");
     ereg ("([0-9]{4})-([0-9]{1,2})-([0-9]{1,2}) ([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})", $time, $datetime);
@@ -748,13 +750,13 @@ function newlinkgraphic($datetime, $time) {
 	$daysold = date("d-M-Y", $startdate);
         if ("$daysold" == "$datetime") {
     	    if ($count<=1) {
-		echo "<img src=\"images/links/newred.gif\" alt=\""._NEWTODAY."\">";
+		echo "<img src=\"modules/$module_name/images/newred.gif\" alt=\""._NEWTODAY."\">";
 	    }
             if ($count<=3 && $count>1) {
-		echo "<img src=\"images/links/newgreen.gif\" alt=\""._NEWLAST3DAYS."\">";
+		echo "<img src=\"modules/$module_name/images/newgreen.gif\" alt=\""._NEWLAST3DAYS."\">";
 	    }
             if ($count<=7 && $count>3) {
-		echo "<img src=\"images/links/newblue.gif\" alt=\""._NEWTHISWEEK."\">";
+		echo "<img src=\"modules/$module_name/images/newblue.gif\" alt=\""._NEWTHISWEEK."\">";
 	    }
 	}
         $count++;
@@ -763,7 +765,7 @@ function newlinkgraphic($datetime, $time) {
 }
 
 function categorynewlinkgraphic($cat) {
-    global $prefix, $dbi;
+    global $prefix, $dbi, $module_name;
     $newresult = sql_query("select date from ".$prefix."_links_links where cid=$cat order by date desc limit 1", $dbi);
     list($time)=sql_fetch_row($newresult, $dbi);
     echo "&nbsp;";
@@ -777,13 +779,13 @@ function categorynewlinkgraphic($cat) {
 	$daysold = date("d-M-Y", $startdate);
         if ("$daysold" == "$datetime") {
     	    if ($count<=1) {
-		echo "<img src=\"images/links/newred.gif\" alt=\""._CATNEWTODAY."\">";
+		echo "<img src=\"modules/$module_name/images/newred.gif\" alt=\""._CATNEWTODAY."\">";
 	    }
             if ($count<=3 && $count>1) {
-		echo "<img src=\"images/links/newgreen.gif\" alt=\""._CATLAST3DAYS."\">";
+		echo "<img src=\"modules/$module_name/images/newgreen.gif\" alt=\""._CATLAST3DAYS."\">";
 	    }
             if ($count<=7 && $count>3) {
-		echo "<img src=\"images/links/newblue.gif\" alt=\""._CATTHISWEEK."\">";
+		echo "<img src=\"modules/$module_name/images/newblue.gif\" alt=\""._CATTHISWEEK."\">";
 	    }
 	}
         $count++;
@@ -792,9 +794,10 @@ function categorynewlinkgraphic($cat) {
 }
 
 function popgraphic($hits) {
+    global $module_name;
     include("modules/Web_Links/l_config.php");
     if ($hits>=$popular) {
-	echo "&nbsp;<img src=\"images/links/pop.gif\" alt=\""._POPULAR."\">";
+	echo "&nbsp;<img src=\"modules/$module_name/images/pop.gif\" alt=\""._POPULAR."\">";
     }
 }
 
@@ -882,23 +885,23 @@ function search($query, $min, $orderby, $show) {
     	    list($cid3,$title3,$parentid3) = sql_fetch_row($result3, $dbi);
     		if ($parentid3>0) $title3 = getparent($parentid3,$title3);
     		$title3 = ereg_replace($query, "<b>$query</b>", $title3);
-    		echo "<strong><big></big></strong>&nbsp;<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlink&amp;cid=$cid\">$title3</a> ($numrows)<br>";
+    		echo "<strong><big></big></strong>&nbsp;<a href=\"modules.php?name=Web_Links&l_op=viewlink&amp;cid=$cid\">$title3</a> ($numrows)<br>";
 		}
 
 	echo "<br><table width=\"100%\" bgcolor=\"$bgcolor2\"><tr><td><font class=\"option\"><b>"._LINKS."</b></font></td></tr></table>";
     	$orderbyTrans = convertorderbytrans($orderby);
     	echo "<br><font class=\"content\">"._SORTLINKSBY.": "
-    	    .""._TITLE." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=titleA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=titleD\">D</a>)"
-    	    .""._DATE." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=dateA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=dateD\">D</a>)"
-    	    .""._RATING." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=ratingA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=ratingD\">D</a>)"
-    	    .""._POPULARITY." (<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=hitsA\">A</a>\<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;orderby=hitsD\">D</a>)"
+    	    .""._TITLE." (<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=titleA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=titleD\">D</a>)"
+    	    .""._DATE." (<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=dateA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=dateD\">D</a>)"
+    	    .""._RATING." (<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=ratingA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=ratingD\">D</a>)"
+    	    .""._POPULARITY." (<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=hitsA\">A</a>\<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;orderby=hitsD\">D</a>)"
     	    ."<br>"._SITESSORTED.": $orderbyTrans<br><br>";
     	while(list($lid, $cid, $sid, $title, $url, $description, $time, $hits, $linkratingsummary, $totalvotes, $totalcomments) = sql_fetch_row($result, $dbi)) {
 	    $linkratingsummary = number_format($linkratingsummary, $mainvotedecimal);
 	    $title = stripslashes($title); $description = stripslashes($description);
 	    $transfertitle = str_replace (" ", "_", $title);
 	    $title = ereg_replace($query, "<b>$query</b>", $title);
-	    echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
+	    echo "<a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"new\">$title</a>";
 	    newlinkgraphic($datetime, $time);
     	    popgraphic($hits);
 	    echo "<br>";
@@ -918,12 +921,12 @@ function search($query, $min, $orderby, $show) {
     	    if ($linkratingsummary!="0" || $linkratingsummary!="0.0") {
 		echo " "._RATING.": $linkratingsummary ($totalvotes $votestring)";
 	    }
-    	    echo "<br><a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
+    	    echo "<br><a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$transfertitle\">"._RATESITE."</a>";
     	    if ($totalvotes != 0) {
-		echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
+		echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkdetails&amp;lid=$lid&amp;ttitle=$transfertitle\">"._DETAILS."</a>";
 	    }
     	    if ($totalcomments != 0) {
-		echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle>"._SCOMMENTS." ($totalcomments)</a>";
+		echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkcomments&amp;lid=$lid&amp;ttitle=$transfertitle>"._SCOMMENTS." ($totalcomments)</a>";
 	    }
 	    detecteditorial($lid, $transfertitle);
 	    echo "<br>";
@@ -955,7 +958,7 @@ function search($query, $min, $orderby, $show) {
 	    .""._SELECTPAGE.": ";
 	$prev=$min-$linksresults;
 	if ($prev>=0) {
-    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;min=$prev&amp;orderby=$orderby&amp;show=$show\">"
+    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;min=$prev&amp;orderby=$orderby&amp;show=$show\">"
     		." &lt;&lt; "._PREVIOUS."</a> ]</b> ";
       	}
 	$counter = 1;
@@ -966,13 +969,13 @@ function search($query, $min, $orderby, $show) {
             if ($counter == $currentpage) {
 		echo "<b>$counter</b> ";
 	    } else {
-		echo "<a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;min=$mintemp&amp;orderby=$orderby&amp;show=$show\">$counter</a> ";
+		echo "<a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;min=$mintemp&amp;orderby=$orderby&amp;show=$show\">$counter</a> ";
 	    }
             $counter++;
         }
         $next=$min+$linksresults;
         if ($x>=$perpage) {
-    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=search&amp;query=$the_query&amp;min=$max&amp;orderby=$orderby&amp;show=$show\">"
+    	    echo "&nbsp;&nbsp;<b>[ <a href=\"modules.php?name=Web_Links&l_op=search&amp;query=$the_query&amp;min=$max&amp;orderby=$orderby&amp;show=$show\">"
     		." "._NEXT." &gt;&gt;</a> ]</b>";
         }
     }
@@ -1044,12 +1047,12 @@ function detecteditorial($lid, $ttitle) {
     $resulted2 = sql_query("select adminid from ".$prefix."_links_editorials where linkid=$lid", $dbi);
     $recordexist = sql_num_rows($resulted2, $dbi);
     if ($recordexist != 0) {
-	echo " | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=viewlinkeditorial&amp;lid=$lid&amp;ttitle=$ttitle\">"._EDITORIAL."</a>";
+	echo " | <a href=\"modules.php?name=Web_Links&l_op=viewlinkeditorial&amp;lid=$lid&amp;ttitle=$ttitle\">"._EDITORIAL."</a>";
     }
 }
 
 function viewlinkcomments($lid, $ttitle) {
-    global $prefix, $dbi, $admin, $bgcolor2;
+    global $prefix, $dbi, $admin, $bgcolor2, $module_name;
     include("header.php");
     include("modules/Web_Links/l_config.php");
     menu(1);
@@ -1101,7 +1104,7 @@ function viewlinkcomments($lid, $ttitle) {
 	    ."<td colspan=\"3\">"
 	    ."<font class=\"content\">";
 	    if (is_admin($admin)) {
-		echo "<a href=\"admin.php?op=LinksModLink&amp;lid=$lid\"><img src=\"images/links/editicon.gif\" border=\"0\" alt=\""._EDITTHISLINK."\"></a>";
+		echo "<a href=\"admin.php?op=LinksModLink&amp;lid=$lid\"><img src=\"modules/$module_name/images/editicon.gif\" border=\"0\" alt=\""._EDITTHISLINK."\"></a>";
 	    }
 	echo " $ratingcomments</font>"
 	    ."<br><br><br></td></tr>";
@@ -1448,18 +1451,19 @@ function viewlinkdetails($lid, $ttitle) {
 }
 
 function linkfooter($lid,$ttitle) {
-    echo "<font class=\"content\">[ <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=visit&amp;lid=$lid\" target=\"_blank\">"._VISITTHISSITE."</a> | <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid&amp;ttitle=$ttitle\">"._RATETHISSITE."</a> ]</font><br><br>";
+    echo "<font class=\"content\">[ <a href=\"modules.php?name=Web_Links&l_op=visit&amp;lid=$lid\" target=\"_blank\">"._VISITTHISSITE."</a> | <a href=\"modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid&amp;ttitle=$ttitle\">"._RATETHISSITE."</a> ]</font><br><br>";
     linkfooterchild($lid);
 }
 
 function linkfooterchild($lid) {
     include("modules/Web_Links/l_config.php");
     if ($useoutsidevoting = 1) {
-	echo "<br><font class=\"content\">"._ISTHISYOURSITE." <a href=\"modules.php?op=modload&name=Web_Links&file=index&l_op=outsidelinksetup&amp;lid=$lid\">"._ALLOWTORATE."</a></font>";
+	echo "<br><font class=\"content\">"._ISTHISYOURSITE." <a href=\"modules.php?name=Web_Links&l_op=outsidelinksetup&amp;lid=$lid\">"._ALLOWTORATE."</a></font>";
     }
 }
 
 function outsidelinksetup($lid) {
+    global $module_name, $sitename, $nukeurl;
     include("header.php");
     include("modules/Web_Links/l_config.php");
     menu(1);
@@ -1472,9 +1476,9 @@ function outsidelinksetup($lid) {
     <b>1) "._TEXTLINK."</b><br><br>
 
     "._PROMOTE02."<br><br>
-    <center><a href=\"$nukeurl/modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&amp;lid=$lid\">"._RATETHISSITE." @ $sitename</a></center><br><br>
+    <center><a href=\"$nukeurl/modules.php?name=Web_Links&l_op=ratelink&amp;lid=$lid\">"._RATETHISSITE." @ $sitename</a></center><br><br>
     <center>"._HTMLCODE1."</center><br>
-    <center><i>&lt;a href=\"$nukeurl/modules.php?op=modload&name=Web_Links&file=index&l_op=ratelink&lid=$lid\"&gt;"._RATETHISSITE."&lt;/a&gt;</i></center>
+    <center><i>&lt;a href=\"$nukeurl/modules.php?name=Web_Links&l_op=ratelink&lid=$lid\"&gt;"._RATETHISSITE."&lt;/a&gt;</i></center>
     <br><br>
     "._THENUMBER." \"$lid\" "._IDREFER."<br><br>
 
