@@ -15,50 +15,13 @@
 if (!eregi("modules.php", $PHP_SELF)) {
 	die ("You can't access this file directly...");
 }
+
 require_once("mainfile.php");
 $module_name = basename(dirname(__FILE__));
 get_lang($module_name);
 $userpage = 1;
 
-function nav() {
-    $handle=opendir('themes');
-    while ($file = readdir($handle)) {
-	if ( (!ereg("[.]",$file)) ) {
-		$thmcount++;
-	}
-    }
-    closedir($handle);
-    echo "<table border=\"0\" cellpadding=\"15\" align=\"center\"><tr><td>";
-
-    echo "<font class=\"content\">"
-	."<center><a href=\"modules.php?name=Your_Account&amp;op=edituser\"><img src=\"images/menu/info.gif\" border=\"0\" alt=\""._CHANGEYOURINFO."\"></a><br>"
-	."<a href=\"modules.php?name=Your_Account&amp;op=edituser\">"._CHANGEYOURINFO."</a>"
-	."</center></font></td>";
-
-    echo "<td><font class=\"content\">"
-	."<center><a href=\"modules.php?name=Your_Account&amp;op=edithome\"><img src=\"images/menu/home.gif\" border=\"0\" alt=\""._CHANGEHOME."\"></a><br>"
-	."<a href=\"modules.php?name=Your_Account&amp;op=edithome\">"._CHANGEHOME."</a>"
-	."</center></form></font></td>";
-
-    echo "<td><font class=\"content\">"
-	."<center><a href=\"modules.php?name=Your_Account&amp;op=editcomm\"><img src=\"images/menu/comments.gif\" border=\"0\" alt=\""._CONFIGCOMMENTS."\"></a><br>"
-	."<a href=\"modules.php?name=Your_Account&amp;op=editcomm\">"._CONFIGCOMMENTS."</a>"
-	."</center></form></font></td>";
-
-    if ($thmcount > 1) {
-	echo "<td><font class=\"content\">"
-	    ."<center><a href=\"modules.php?name=Your_Account&amp;op=chgtheme\"><img src=\"images/menu/themes.gif\" border=\"0\" alt=\""._SELECTTHETHEME."\"></a><br>"
-	    ."<a href=\"modules.php?name=Your_Account&amp;op=chgtheme\">"._SELECTTHETHEME."</a>"
-	    ."</center></form></font></td>";
-    }
-    
-    echo "<td><font class=\"content\">"
-	."<center><a href=\"modules.php?name=Your_Account&amp;op=logout\"><img src=\"images/menu/exit.gif\" border=\"0\" alt=\""._LOGOUTEXIT."\"></a><br>"
-	."<a href=\"modules.php?name=Your_Account&amp;op=logout\">"._LOGOUTEXIT."</a>"
-	."</center></form></font>";
-
-    echo "</td></tr></table>\n";
-}
+include("modules/$module_name/navbar.php");
 
 function userCheck($uname, $email) {
     global $stop, $user_prefix, $dbi;
@@ -74,22 +37,19 @@ function userCheck($uname, $email) {
 }
 
 function makePass() {
-    $makepass="";
-    $syllables="er,in,tia,wol,fe,pre,vet,jo,nes,al,len,son,cha,ir,ler,bo,ok,tio,nar,sim,ple,bla,ten,toe,cho,co,lat,spe,ak,er,po,co,lor,pen,cil,li,ght,wh,at,the,he,ck,is,mam,bo,no,fi,ve,any,way,pol,iti,cs,ra,dio,sou,rce,sea,rch,pa,per,com,bo,sp,eak,st,fi,rst,gr,oup,boy,ea,gle,tr,ail,bi,ble,brb,pri,dee,kay,en,be,se";
-    $syllable_array=explode(",", $syllables);
-    srand((double)microtime()*1000000);
-    for ($count=1;$count<=4;$count++) {
-	if (rand()%10 == 1) {
-	    $makepass .= sprintf("%0.0f",(rand()%50)+1);
-	} else {
-	    $makepass .= sprintf("%s",$syllable_array[rand()%62]);
-	}
+    $cons = "bcdfghjklmnpqrstvwxyz";
+    $vocs = "aeiou";
+    for ($x=0; $x < 6; $x++) {
+	mt_srand ((double) microtime() * 1000000);
+	$con[$x] = substr($cons, mt_rand(0, strlen($cons)-1), 1);
+	$voc[$x] = substr($vocs, mt_rand(0, strlen($vocs)-1), 1);
     }
+    $makepass = $con[0] . $voc[0] .$con[2] . $con[1] . $voc[1] . $con[3] . $voc[3] . $con[4];
     return($makepass);
 }
 
 function confirmNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ, $user_from, $user_intrest, $user_sig, $user_viewemail, $user_aim, $user_yim, $user_msnm) {
-    global $stop, $EditedMessage, $sitename;
+    global $stop, $EditedMessage, $sitename, $module_name;
     include("header.php");
     filter_text($uname);
     $uname = $EditedMessage;
@@ -115,7 +75,7 @@ function confirmNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ
 	if (($user_occ) || ($user_occ!="")) echo "<b>"._OCCUPATION.":</b> $user_occ<br>";
 	if (($user_intrest) || ($user_intrest!="")) echo "<b>"._INTERESTS.":</b> $user_intrest<br>";			
 	if (($user_sig) || ($user_sig!="")) echo "<b>"._SIGNATURE.":</b> $user_sig<br>";
-	echo "<form action=\"modules.php?name=Your_Account\" method=\"post\">"
+	echo "<form action=\"modules.php?name=$module_name\" method=\"post\">"
 	    ."<input type=\"hidden\" name=\"uname\" value=\"$uname\">"
 	    ."<input type=\"hidden\" name=\"email\" value=\"$email\">"
 	    ."<input type=\"hidden\" name=\"user_avatar\" value=\"$user_avatar\">"
@@ -149,7 +109,7 @@ function finishNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ,
     if (!isset($stop)) {
 	$makepass=makepass();
 	$cryptpass = md5($makepass);
-	$result = sql_query("insert into ".$user_prefix."_users values (NULL,'','$uname','$email','','$url','$user_avatar','$user_regdate','$user_icq','$user_occ','$user_from','$user_intrest','$user_sig','$user_viewemail','','$user_aim','$user_yim','$user_msnm','$cryptpass','$storyhome','','0','0','0','','0','','$Default_Theme','$commentlimit','0','0','0','0','0','1')", $dbi);
+	$result = sql_query("insert into ".$user_prefix."_users values (NULL,'','$uname','$email','','$url','$user_avatar','$user_regdate','$user_icq','$user_occ','$user_from','$user_intrest','$user_sig','$user_viewemail','','$user_aim','$user_yim','$user_msnm','$cryptpass','$storyhome','','0','0','0','','0','','$Default_Theme','$commentlimit','0','0','0','0','0','1','1','0')", $dbi);
 	if(!$result) {
 	    echo ""._ERROR."<br>";
 	} else {
@@ -172,8 +132,8 @@ function finishNewUser($uname, $email, $url, $user_avatar, $user_icq, $user_occ,
     include("footer.php");
 }
 
-function userinfo($uname, $bypass=0) {
-    global $user, $cookie, $sitename, $prefix, $user_prefix, $dbi, $admin;
+function userinfo($uname, $bypass=0, $hid=0, $url=0) {
+    global $user, $cookie, $sitename, $prefix, $user_prefix, $dbi, $admin, $broadcast_msg, $my_headlines, $module_name;
     $result = sql_query("select uid, femail, url, bio, user_avatar, user_icq, user_aim, user_yim, user_msnm, user_from, user_occ, user_intrest, user_sig, pass, newsletter from ".$user_prefix."_users where uname='$uname'", $dbi);
     $userinfo = sql_fetch_array($result, $dbi);
     if(!$bypass) cookiedecode($user);
@@ -183,7 +143,8 @@ function userinfo($uname, $bypass=0) {
     if(($uname == $cookie[1]) AND ($userinfo[pass] == $cookie[2])) {
 	echo "<font class=\"option\">$uname, "._WELCOMETO." $sitename!</font><br><br>";
 	echo "<font class=\"content\">"._THISISYOURPAGE."</font></center><br><br>";
-	nav();
+	nav(1);
+	echo "<br><br>";
     } else {
 	echo "<font class=\"title\">"._PERSONALINFO.": $uname</font></center><br><br>";
     }
@@ -195,7 +156,7 @@ function userinfo($uname, $bypass=0) {
     if((sql_num_rows($result, $dbi)==1) && ($userinfo[url] || $userinfo[femail] || $userinfo[bio] || $userinfo[user_avatar] || $userinfo[user_icq] || $userinfo[user_aim] || $userinfo[user_yim] || $userinfo[user_msnm] || $userinfo[user_location] || $userinfo[user_occ] || $userinfo[user_intrest] || $userinfo[user_sig])) {
 	echo "<center><font class=\"content\">";
 	if ($userinfo[user_avatar]) echo "<img src=\"images/forum/avatar/$userinfo[user_avatar]\" alt=\"\"><br>\n";
-	if ($userinfo[url]) { echo ""._MYHOMEPAGE." <a href=\"$userinfo[url]\" target=\"new\">$userinfo[url]</a><br>\n"; }
+	if ($userinfo[url] != "http://" AND $userinfo[url] != "") { echo ""._MYHOMEPAGE." <a href=\"$userinfo[url]\" target=\"new\">$userinfo[url]</a><br>\n"; }
 	if ($userinfo[femail]) { echo ""._MYEMAIL." <a href=\"mailto:$userinfo[femail]\">$userinfo[femail]</a><br>\n"; }
 	if ($userinfo[user_icq]) echo ""._ICQ.": $userinfo[user_icq]<br>\n";
 	if ($userinfo[user_aim]) echo ""._AIM.": $userinfo[user_aim]<br>\n";
@@ -220,6 +181,13 @@ function userinfo($uname, $bypass=0) {
 	} elseif (($userinfo[newsletter] == 0) AND ($uname == $cookie[1]) AND ($userinfo[pass] == $cookie[2]) OR (is_admin($admin) AND ($userinfo[newsletter] == 0))) {
 	    echo "<i>"._NOTSUBSCRIBED."</i><br>";
 	}
+	if (is_active("Journal") AND $cookie[1] != $uname) {
+	    $result = sql_query("select jid from ".$prefix."_journal where aid='$uname' AND status='yes' order by pdate,jid DESC limit 0,1", $dbi);
+	    list($jid) = sql_fetch_row($result, $dbi);
+	    if ($jid != "" AND isset($jid)) {
+		echo "[ <a href=\"modules.php?name=Journal&amp;file=search&amp;bywhat=aid&amp;forwhat=$uname\">"._READMYJOURNAL."</a> ]<br>";
+	    }
+	}
 	if (is_admin($admin)) {
 	    echo "[ <a href=\"admin.php?op=modifyUser&chng_uid=$userinfo[uid]\">"._EDITUSER."</a> ]<br>";
 	}
@@ -229,7 +197,110 @@ function userinfo($uname, $bypass=0) {
 	echo "<center>"._NOINFOFOR." $uname</center>";
     }
     CloseTable();
-    if (is_active("Private_Messages")) {
+    if ($my_headlines == 1 AND ($uname == $cookie[1]) AND ($userinfo[pass] == $cookie[2])) {
+    echo "<br>";
+    OpenTable();
+    echo "<center><b>"._MYHEADLINES."</b><br><br>"
+	.""._SELECTASITE."<br><br>"
+	."<form action=\"modules.php?name=$module_name\" method=\"post\">"
+	."<input type=\"hidden\" name=\"op\" value=\"userinfo\">"
+	."<input type=\"hidden\" name=\"uname\" value=\"$uname\">"
+	."<input type=\"hidden\" name=\"bypass\" value=\"$bypass\">"
+	."<input type=\"hidden\" name=\"url\" value=\"0\">"
+	."<select name=\"hid\" onChange='submit()'>\n"
+	."<option value=\"0\">"._SELECTASITE2."</option>";
+    $headl = sql_query("select hid, sitename from ".$prefix."_headlines order by sitename", $dbi);
+    while(list($nhid, $hsitename) = sql_fetch_row($headl, $dbi)) {
+	if ($hid == $nhid ) {
+	    $sel = "selected";
+	} else {
+	    $sel = "";
+	}
+	echo "<option value=\"$nhid\" $sel>$hsitename</option>\n";
+    }
+    echo "</select></form>"
+	.""._ORTYPEURL."<br><br>"
+	."<form action=\"modules.php?name=$module_name\" method=\"post\">"
+	."<input type=\"hidden\" name=\"op\" value=\"userinfo\">"
+	."<input type=\"hidden\" name=\"uname\" value=\"$uname\">"
+	."<input type=\"hidden\" name=\"bypass\" value=\"$bypass\">"
+	."<input type=\"hidden\" name=\"hid\" value=\"0\">"
+	."<input type=\"text\" name=\"url\" size=\"40\" maxlength=\"200\" value=\"http://\">&nbsp;&nbsp;"
+	."<input type=\"submit\" value=\""._GO."\"></form>"
+	."</center><br>";
+    if ($hid != 0 OR ($hid == 0 AND $url != "0" AND $url != "http://") AND $url != "") {
+	if ($hid != 0) {
+    	    $result = sql_query("select sitename, headlinesurl from ".$prefix."_headlines where hid='$hid'", $dbi);
+	    list($nsitename, $url) = sql_fetch_row($result, $dbi);
+	    $title = $nsitename;
+	    $siteurl = eregi_replace("http://", "", $url);
+	    $siteurl = explode("/", $siteurl);
+	} else {
+	    if (!ereg("http://", $url)) {
+		$url = "http://$url";
+	    }
+	    $siteurl = eregi_replace("http://", "", $url);
+	    $siteurl = explode("/", $siteurl);
+	    $title = "http://$siteurl[0]";
+	}
+	$rdf = parse_url($url);
+	$fp = fsockopen($rdf['host'], 80, $errno, $errstr, 15);
+	if (!$fp) {
+    	    $content = "<center><font class=\"content\">"._RSSPROBLEM."</font></center>";
+	}
+	if ($fp) {
+    	    fputs($fp, "GET " . $rdf['path'] . "?" . $rdf['query'] . " HTTP/1.0\r\n");
+    	    fputs($fp, "HOST: " . $rdf['host'] . "\r\n\r\n");
+    	    $string	= "";
+    	    while(!feof($fp)) {
+		$pagetext = fgets($fp,300);
+		$string .= chop($pagetext);
+	    }
+	    fputs($fp,"Connection: close\r\n\r\n");
+	    fclose($fp);
+	    $items = explode("</item>",$string);
+	    $content = "<font class=\"content\">";
+	    for ($i=0;$i<10;$i++) {
+		$link = ereg_replace(".*<link>","",$items[$i]);
+		$link = ereg_replace("</link>.*","",$link);
+		$title2 = ereg_replace(".*<title>","",$items[$i]);
+		$title2 = ereg_replace("</title>.*","",$title2);
+		if ($items[$i] == "" AND $cont != 1) {
+	    	    $content = "<center>"._RSSPROBLEM."</center>";
+		} else {
+	    	    if (strcmp($link,$title2) AND $items[$i] != "") {
+	    		$cont = 1;
+			$content .= "<img src=\"images/arrow.gif\" border=\"0\" hspace=\"5\"><a href=\"$link\" target=\"new\">$title2</a><br>\n";
+		    }
+		}
+	    }
+	}
+	if ($content != "") {
+	    OpenTable2();
+	    echo "<center><b>"._HEADLINESFROM." <a href=\"http://$siteurl[0]\" target=\"new\">$title</a></b></center><br>";
+	    echo "$content";
+	    CloseTable2();
+	} elseif (($cont == 0) OR ($content == "")) {
+	    OpenTable2();
+	    echo "<center>"._RSSPROBLEM."</center><br>";
+	    CloseTable2();
+	}
+	echo "<br>";
+    }
+    CloseTable();
+    }
+    if ($broadcast_msg == 1 AND ($uname == $cookie[1]) AND ($userinfo[pass] == $cookie[2])) {
+	echo "<br>";
+	OpenTable();
+	echo "<center><b>"._BROADCAST."</b><br><br>"._BROADCASTTEXT."<br><br>"
+	    ."<form action=\"modules.php?name=$module_name\" method=\"post\">"
+	    ."<input type=\"hidden\" name=\"who\" value=\"$uname\">"
+	    ."<input type=\"hidden\" name=\"op\" value=\"broadcast\">"
+	    ."<input type=\"text\" size=\"60\" maxlength=\"255\" name=\"the_message\">&nbsp;&nbsp;<input type=\"submit\" value=\""._SEND."\">"
+	    ."</form></center>";
+	CloseTable();
+    }
+    if (is_active("Private_Messages") AND ($uname == $cookie[1]) AND ($userinfo[pass] == $cookie[2])) {
 	echo "<br>";
 	OpenTable();
 	echo "<center><b>"._PRIVATEMESSAGES."</b><br><br>";
@@ -279,7 +350,7 @@ function userinfo($uname, $bypass=0) {
 }
 
 function main($user) {
-    global $stop;
+    global $stop, $module_name;
     if(!is_user($user)) {
 	include("header.php");
 	if ($stop) {
@@ -295,14 +366,14 @@ function main($user) {
 	}
 	if (!is_user($user)) {
 	    OpenTable();
-	    echo "<form action=\"modules.php?name=Your_Account\" method=\"post\">\n"
+	    echo "<form action=\"modules.php?name=$module_name\" method=\"post\">\n"
 		."<b>"._USERLOGIN."</b><br><br>\n"
 		."<table border=\"0\"><tr><td>\n"
 		.""._NICKNAME.":</td><td><input type=\"text\" name=\"uname\" size=\"15\" maxlength=\"25\"></td></tr>\n"
 		."<tr><td>"._PASSWORD.":</td><td><input type=\"password\" name=\"pass\" size=\"15\" maxlength=\"20\"></td></tr></table>\n"
 		."<input type=\"hidden\" name=\"op\" value=\"login\">\n"
 		."<input type=\"submit\" value=\""._LOGIN."\"></form><br>\n\n"
-		."<center><font class=\"content\">[ <a href=\"modules.php?name=Your_Account&amp;op=pass_lost\">"._PASSWORDLOST."</a> | <a href=\"modules.php?name=Your_Account&amp;op=new_user\">"._REGNEWUSER."</a> ]</font></center>\n";
+		."<center><font class=\"content\">[ <a href=\"modules.php?name=$module_name&amp;op=pass_lost\">"._PASSWORDLOST."</a> | <a href=\"modules.php?name=$module_name&amp;op=new_user\">"._REGNEWUSER."</a> ]</font></center>\n";
 	    CloseTable();
 	}
 	include("footer.php");
@@ -314,6 +385,7 @@ function main($user) {
 }
 
 function new_user() {
+    global $my_headlines, $module_name;
     if (!is_user($user)) {
 	include("header.php");
 	OpenTable();
@@ -321,13 +393,13 @@ function new_user() {
 	CloseTable();
 	echo "<br>\n";
 	OpenTable();
-	echo "<form name=\"Register\" action=\"modules.php?name=Your_Account\" method=\"post\">\n"
+	echo "<form name=\"Register\" action=\"modules.php?name=$module_name\" method=\"post\">\n"
     	    ."<b>"._REGNEWUSER."</b><br><br>\n"
 	    ."<table cellpadding=\"0\" cellspacing=\"10\" border=\"0\">\n"
     	    ."<tr><td>"._NICKNAME.":</td><td><input type=\"text\" name=\"uname\" size=\"30\" maxlength=\"25\"> <font class=\"tiny\">"._REQUIRED."</font></td></tr>\n"
     	    ."<tr><td>"._EMAIL.":</td><td><input type=\"text\" name=\"email\" size=\"30\" maxlength=\"255\"> <font class=\"tiny\">"._REQUIRED."</font></td></tr>\n"
     	    ."<tr><td>"._WEBSITE.":</td><td><input type=\"text\" name=\"url\" size=\"30\" maxlength=\"255\"></td></tr>\n"
-    	    ."<tr><td>"._AVATAR.":</td><td>[ <a href=\"modules.php?name=Your_Account&amp;op=avatarlist\">"._LIST."</a> ]&nbsp;&nbsp;\n"
+    	    ."<tr><td>"._AVATAR.":</td><td>[ <a href=\"modules.php?name=$module_name&amp;op=avatarlist\">"._LIST."</a> ]&nbsp;&nbsp;\n"
     	    ."<select name=\"user_avatar\" onChange=\"showimage()\">\n";
         $direktori = "images/forum/avatar";
         $handle=opendir($direktori);
@@ -373,13 +445,40 @@ function new_user() {
     	    ."<li>"._ASREG2."\n"
     	    ."<li>"._ASREG3."\n"
     	    ."<li>"._ASREG4."\n"
-    	    ."<li>"._ASREG5."\n"
-    	    ."<li>"._ASREG6."\n"
-    	    ."<li>"._ASREG7."\n"
+    	    ."<li>"._ASREG5."\n";
+	$handle=opendir('themes');
+	    while ($file = readdir($handle)) {
+	    if ((!ereg("[.]",$file) AND file_exists("themes/$file/theme.php"))) {
+		$thmcount++;
+	    }
+	}
+	closedir($handle);
+    	if ($thmcount > 1) {
+	    echo "<li>"._ASREG6."\n";
+	}
+	$result = sql_query("select custom_title from ".$prefix."_modules WHERE active='1' AND view='1'", $dbi);
+	while (list($custom_title) = sql_fetch_row($result, $dbi)) {
+	    if ($custom_title != "") {
+		echo "<li>"._ACCESSTO." $custom_title\n";
+	    }
+	}
+	$result = sql_query("select title from ".$prefix."_blocks WHERE active='1' AND view='1'", $dbi);
+	while (list($b_title) = sql_fetch_row($result, $dbi)) {
+	    if ($b_title != "") {
+		echo "<li>"._ACCESSTO." $b_title\n";
+	    }
+	}
+	if (is_active("Journal")) {
+	    echo "<li>"._CREATEJOURNAL."\n";
+	}
+	if ($my_headlines == 1) {
+	    echo "<li>"._READHEADLINES."\n";
+	}
+    	echo "<li>"._ASREG7."\n"
 	    ."</ul>\n"
     	    .""._REGISTERNOW."<br>\n"
     	    .""._WEDONTGIVE."<br><br>\n"
-	    ."<center><font class=\"content\">[ <a href=\"modules.php?name=Your_Account\">"._USERLOGIN."</a> | <a href=\"modules.php?name=Your_Account&amp;op=pass_lost\">"._PASSWORDLOST."</a> ]</font></center>\n";
+	    ."<center><font class=\"content\">[ <a href=\"modules.php?name=$module_name\">"._USERLOGIN."</a> | <a href=\"modules.php?name=$module_name&amp;op=pass_lost\">"._PASSWORDLOST."</a> ]</font></center>\n";
 	CloseTable();
 	include("footer.php");
     } elseif (is_user($user)) {
@@ -390,7 +489,7 @@ function new_user() {
 }
 
 function pass_lost() {
-    global $user;
+    global $user, $module_name;
     if (!is_user($user)) {
 	include("header.php");
 	OpenTable();
@@ -400,13 +499,13 @@ function pass_lost() {
 	OpenTable();
 	echo "<b>"._PASSWORDLOST."</b><br><br>\n"
     	    .""._NOPROBLEM."<br><br>\n"
-	    ."<form action=\"modules.php?name=Your_Account\" method=\"post\">\n"
+	    ."<form action=\"modules.php?name=$module_name\" method=\"post\">\n"
 	    ."<table border=\"0\"><tr><td>\n"
     	    .""._NICKNAME.":</td><td><input type=\"text\" name=\"uname\" size=\"15\" maxlength=\"25\"></td></tr>\n"
     	    ."<tr><td>"._CONFIRMATIONCODE.":</td><td><input type=\"text\" name=\"code\" size=\"11\" maxlength=\"10\"></td></tr></table><br>\n"
     	    ."<input type=\"hidden\" name=\"op\" value=\"mailpasswd\">\n"
     	    ."<input type=\"submit\" value=\""._SENDPASSWORD."\"></form><br>\n"
-	    ."<center><font class=\"content\">[ <a href=\"modules.php?name=Your_Account\">"._USERLOGIN."</a> | <a href=\"modules.php?name=Your_Account&amp;op=new_user\">"._REGNEWUSER."</a> ]</font></center>\n";
+	    ."<center><font class=\"content\">[ <a href=\"modules.php?name=$module_name\">"._USERLOGIN."</a> | <a href=\"modules.php?name=$module_name&amp;op=new_user\">"._REGNEWUSER."</a> ]</font></center>\n";
 	CloseTable();
 	include("footer.php");
     } elseif(is_user($user)) {
@@ -430,19 +529,21 @@ function logout() {
 }
 
 function mail_password($uname, $code) {
-    global $sitename, $adminmail, $nukeurl, $user_prefix, $dbi;
+    global $sitename, $adminmail, $nukeurl, $user_prefix, $dbi, $module_name;
     $result = sql_query("select email, pass from ".$user_prefix."_users where (uname='$uname')", $dbi);
     if(!$result) {
+	include("header.php");
 	OpenTable();
 	echo "<center>"._SORRYNOUSERINFO."</center>";
 	CloseTable();
+	include("footer.php");
     } else {
 	$host_name = getenv("REMOTE_ADDR");
 	list($email, $pass) = sql_fetch_row($result, $dbi);
 	$areyou = substr($pass, 0, 10);
 	if ($areyou==$code) {
 	    $newpass=makepass();
-	    $message = ""._USERACCOUNT." '$uname' "._AT." $sitename "._HASTHISEMAIL."  "._AWEBUSERFROM." $host_name "._HASREQUESTED."\n\n"._YOURNEWPASSWORD." $newpass\n\n "._YOUCANCHANGE." $nukeurl/modules.php?name=Your_Account\n\n"._IFYOUDIDNOTASK."";
+	    $message = ""._USERACCOUNT." '$uname' "._AT." $sitename "._HASTHISEMAIL."  "._AWEBUSERFROM." $host_name "._HASREQUESTED."\n\n"._YOURNEWPASSWORD." $newpass\n\n "._YOUCANCHANGE." $nukeurl/modules.php?name=$module_name\n\n"._IFYOUDIDNOTASK."";
 	    $subject = ""._USERPASSWORD4." $uname";
 	    mail($email, $subject, $message, "From: $adminmail\nX-Mailer: PHP/" . phpversion());
 	    /* Next step: add the new password to the database */
@@ -460,16 +561,22 @@ function mail_password($uname, $code) {
 	} else {
 	    $result = sql_query("select email, pass from ".$user_prefix."_users where (uname='$uname')", $dbi);
 	    if(!$result) {
+		include ("header.php");
+		OpenTable();
 	        echo "<center>"._SORRYNOUSERINFO."</center>";
+		CloseTable();
+		include ("footer.php");
 	    } else {
 	        $host_name = getenv("REMOTE_ADDR");
 	        list($email, $pass) = sql_fetch_row($result, $dbi);
 	        $areyou = substr($pass, 0, 10);
-    		$message = ""._USERACCOUNT." '$uname' "._AT." $sitename "._HASTHISEMAIL." "._AWEBUSERFROM." $host_name "._CODEREQUESTED."\n\n"._YOURCODEIS." $areyou \n\n"._WITHTHISCODE." $nukeurl/modules.php?name=Your_Account&op=pass_lost\n"._IFYOUDIDNOTASK2."";
+    		$message = ""._USERACCOUNT." '$uname' "._AT." $sitename "._HASTHISEMAIL." "._AWEBUSERFROM." $host_name "._CODEREQUESTED."\n\n"._YOURCODEIS." $areyou \n\n"._WITHTHISCODE." $nukeurl/modules.php?name=$module_name&op=pass_lost\n"._IFYOUDIDNOTASK2."";
 		$subject=""._CODEFOR." $uname";
 		mail($email, $subject, $message, "From: $adminmail\nX-Mailer: PHP/" . phpversion());
 		include ("header.php");
-		echo "<center>"._CODEFOR." $uname "._MAILED."";
+		OpenTable();
+		echo "<center>"._CODEFOR." $uname "._MAILED."<br><br>"._GOBACK."</center>";
+		CloseTable();
 		include ("footer.php");
     	    }		
 	}
@@ -478,11 +585,11 @@ function mail_password($uname, $code) {
 
 function docookie($setuid, $setuname, $setpass, $setstorynum, $setumode, $setuorder, $setthold, $setnoscore, $setublockon, $settheme, $setcommentmax) {
     $info = base64_encode("$setuid:$setuname:$setpass:$setstorynum:$setumode:$setuorder:$setthold:$setnoscore:$setublockon:$settheme:$setcommentmax");
-    setcookie("user","$info",time()+15552000);
+    setcookie("user","$info",time()+2592000);
 }
 
 function login($uname, $pass) {
-    global $setinfo, $user_prefix, $dbi;
+    global $setinfo, $user_prefix, $dbi, $module_name;
     $result = sql_query("select pass, uid, storynum, umode, uorder, thold, noscore, ublockon, theme, commentmax from ".$user_prefix."_users where uname='$uname'", $dbi);
     $setinfo = sql_fetch_array($result, $dbi);
     if ((sql_num_rows($result, $dbi)==1) AND ($setinfo[uid] != 1) AND ($setinfo[pass] != "")) {
@@ -496,18 +603,18 @@ function login($uname, $pass) {
 	    list($dbpass) = sql_fetch_row($result, $dbi);
 	}
 	if ($dbpass != $new_pass) {
-            Header("Location: modules.php?name=Your_Account&stop=1");
+            Header("Location: modules.php?name=$module_name&stop=1");
     	    return;
 	}
 	docookie($setinfo[uid], $uname, $new_pass, $setinfo[storynum], $setinfo[umode], $setinfo[uorder], $setinfo[thold], $setinfo[noscore], $setinfo[ublockon], $setinfo[theme], $setinfo[commentmax]);
-	Header("Location: modules.php?name=Your_Account&op=userinfo&bypass=1&uname=$uname");
+	Header("Location: modules.php?name=$module_name&op=userinfo&bypass=1&uname=$uname");
     } else {
-	Header("Location: modules.php?name=Your_Account&stop=1");
+	Header("Location: modules.php?name=$module_name&stop=1");
     }
 }
 
 function edituser() {
-    global $user, $userinfo, $cookie;
+    global $user, $userinfo, $cookie, $module_name;
     getusrinfo($user);
     if (($userinfo[uname] != $cookie[1]) AND ($userinfo[pass] != $cookie[2])) {
     include("header.php");
@@ -524,7 +631,7 @@ function edituser() {
     }
     OpenTable();
     echo "<table cellpadding=\"8\" border=\"0\"><tr><td>"
-	."<form name=\"Register\" action=\"modules.php?name=Your_Account\" method=\"post\">"
+	."<form name=\"Register\" action=\"modules.php?name=$module_name\" method=\"post\">"
 	."<b>"._UREALNAME."</b> "._OPTIONAL."<br>"
 	."<input type=\"text\" name=\"realname\" value=\"$userinfo[name]\" size=\"30\" maxlength=\"60\"><br><br>"
 	."<b>"._UREALEMAIL."</b> "._REQUIRED."<br>"
@@ -535,7 +642,7 @@ function edituser() {
 	."<input type=\"text\" name=\"femail\" value=\"$userinfo[femail]\" size=\"30\" maxlength=\"255\"><br><br>"
 	."<b>"._YOURHOMEPAGE."</b> "._OPTIONAL."<br>"
 	."<input type=\"text\" name=\"url\" value=\"$userinfo[url]\" size=\"30\" maxlength=\"255\"><br><br>"
-	."<b>"._YOURAVATAR."</b> "._OPTIONAL."<br>[ <a href=\"modules.php?name=Your_Account&amp;op=avatarlist\">"._LIST."</a> ]&nbsp;&nbsp;"
+	."<b>"._YOURAVATAR."</b> "._OPTIONAL."<br>[ <a href=\"modules.php?name=$module_name&amp;op=avatarlist\">"._LIST."</a> ]&nbsp;&nbsp;"
 	."<select name=\"user_avatar\" onChange=\"showimage()\">"
 	."<option value=\"$userinfo[user_avatar]\">$userinfo[user_avatar]</option>";
     $direktori = "images/forum/avatar";
@@ -602,7 +709,7 @@ function edituser() {
 
 
 function saveuser($uid, $realname, $uname, $email, $femail, $url, $pass, $vpass, $bio, $user_avatar, $user_icq, $user_occ, $user_from, $user_intrest, $user_sig, $user_aim, $user_yim, $user_msnm, $attach, $newsletter) {
-    global $user, $cookie, $userinfo, $EditedMessage, $user_prefix, $dbi;
+    global $user, $cookie, $userinfo, $EditedMessage, $user_prefix, $dbi, $module_name;
     cookiedecode($user);
     $check = $cookie[1];
     $check2 = $cookie[2];
@@ -639,13 +746,13 @@ function saveuser($uid, $realname, $uname, $email, $femail, $url, $pass, $vpass,
 		$a = 0;
 	    }
 	    }
-	    Header("Location: modules.php?name=Your_Account");
+	    Header("Location: modules.php?name=$module_name");
 	}
     }
 }
 
 function edithome() {
-    global $user, $userinfo, $Default_Theme, $cookie;
+    global $user, $userinfo, $Default_Theme, $cookie, $broadcast_msg, $user_news, $storyhome, $module_name;
     getusrinfo($user);
     if (($userinfo[uname] != $cookie[1]) AND ($userinfo[pass] != $cookie[2])) {
     include ("header.php");
@@ -661,13 +768,37 @@ function edithome() {
         $userinfo[theme] = "$Default_Theme";
     }
     OpenTable();
-    echo "<form action=\"modules.php?name=Your_Account\" method=\"post\">"
-	."<b>"._NEWSINHOME."</b> "._MAX127." "
-	."<input type=\"text\" name=\"storynum\" size=\"3\" maxlength=\"3\" value=\"$userinfo[storynum]\">"
-	."<br><br>";
+    echo "<form action=\"modules.php?name=$module_name\" method=\"post\">";
+    if ($user_news == 1) {
+	echo "<b>"._NEWSINHOME."</b> "._MAX127." "
+	    ."<input type=\"text\" name=\"storynum\" size=\"3\" maxlength=\"3\" value=\"$userinfo[storynum]\">"
+	    ."<br><br>";
+    } else {
+	echo "<input type=\"hidden\" name=\"storynum\" value=\"$storyhome\">";
+    }
+    if ($userinfo[popmeson] == 1) {
+        $sel1 = "checked";
+        $sel2 = "";
+    } elseif ($userinfo[popmeson] == 0) {
+        $sel1 = "";
+        $sel2 = "checked";
+    }
+    echo "<b>"._POPMSGACTIVE."</b> <input type=\"radio\" name=\"popmeson\" value=\"1\" $sel1> "._YES." &nbsp;&nbsp;<input type=\"radio\" name=\"popmeson\" value=\"0\" $sel2>"._NO."<br><br>";
     if ($userinfo[ublockon]==1) {
         $sel = "checked";
     }
+    if ($broadcast_msg == 1) {
+	if ($userinfo[broadcast] == 1) {
+	    $sel1 = "checked";
+	    $sel2 = "";
+	} elseif ($userinfo[broadcast] == 0) {
+	    $sel1 = "";
+	    $sel2 = "checked";
+	}
+	echo "<b>"._MESSAGEACTIVATE."</b> <input type=\"radio\" name=\"broadcast\" value=\"1\" $sel1> "._YES." &nbsp;&nbsp;<input type=\"radio\" name=\"broadcast\" value=\"0\" $sel2>"._NO."<br><br>";
+    } else {
+	echo "<input type=\"hidden\" name=\"broadcast\" value=\"1\">";
+    }
     echo "<input type=\"checkbox\" name=\"ublockon\" $sel>"
 	." <b>"._ACTIVATEPERSONAL."</b>"
 	."<br>"._CHECKTHISOPTION.""
@@ -687,7 +818,7 @@ function edithome() {
 }
 
 function chgtheme() {
-    global $user, $userinfo, $Default_Theme, $cookie;
+    global $user, $userinfo, $Default_Theme, $cookie, $module_name;
     getusrinfo($user);
     if (($userinfo[uname] != $cookie[1]) AND ($userinfo[pass] != $cookie[2])) {
     include ("header.php");
@@ -701,12 +832,12 @@ function chgtheme() {
     echo "<br>";
     OpenTable();
     echo "<center>"
-	."<form action=\"modules.php?name=Your_Account\" method=\"post\">"
+	."<form action=\"modules.php?name=$module_name\" method=\"post\">"
 	."<b>"._SELECTTHEME."</b><br>"
 	."<select name=\"theme\">";
     $handle=opendir('themes');
     while ($file = readdir($handle)) {
-	if ( (!ereg("[.]",$file)) ) {
+	if ( (!ereg("[.]",$file) AND file_exists("themes/$file/theme.php")) ) {
 		$themelist .= "$file ";
 	}
     }
@@ -737,8 +868,8 @@ function chgtheme() {
 }
 
 
-function savehome($uid, $uname, $storynum, $ublockon, $ublock) {
-    global $user, $cookie, $userinfo, $user_prefix, $dbi;
+function savehome($uid, $uname, $storynum, $ublockon, $ublock, $broadcast, $popmeson) {
+    global $user, $cookie, $userinfo, $user_prefix, $dbi, $module_name;
     cookiedecode($user);
     $check = $cookie[1];
     $check2 = $cookie[2];
@@ -747,30 +878,30 @@ function savehome($uid, $uname, $storynum, $ublockon, $ublock) {
     if (($uid == $vuid) AND ($check2 == $ccpass)) {	
 	if(isset($ublockon)) $ublockon=1; else $ublockon=0;	
 	$ublock = FixQuotes($ublock);
-	sql_query("update ".$user_prefix."_users set storynum='$storynum', ublockon='$ublockon', ublock='$ublock' where uid=$uid", $dbi);
+	sql_query("update ".$user_prefix."_users set storynum='$storynum', ublockon='$ublockon', ublock='$ublock', broadcast='$broadcast', popmeson='$popmeson' where uid='$uid'", $dbi);
 	getusrinfo($user);
 	docookie($userinfo[uid],$userinfo[uname],$userinfo[pass],$userinfo[storynum],$userinfo[umode],$userinfo[uorder],$userinfo[thold],$userinfo[noscore],$userinfo[ublockon],$userinfo[theme],$userinfo[commentmax]);
-	Header("Location: modules.php?name=Your_Account");
+	Header("Location: modules.php?name=$module_name");
     }
 }
 
 function savetheme($uid, $theme) {
-    global $user, $cookie, $userinfo, $user_prefix, $dbi;
+    global $user, $cookie, $userinfo, $user_prefix, $dbi, $module_name;
     cookiedecode($user);
     $check = $cookie[1];
     $check2 = $cookie[2];
     $result = sql_query("select uid, pass from ".$user_prefix."_users where uname='$check'", $dbi);
     list($vuid, $ccpass) = sql_fetch_row($result, $dbi);
     if (($uid == $vuid) AND ($check2 == $ccpass)) {
-	sql_query("update ".$user_prefix."_users set theme='$theme' where uid=$uid", $dbi);
+	sql_query("update ".$user_prefix."_users set theme='$theme' where uid='$uid'", $dbi);
 	getusrinfo($user);
 	docookie($userinfo[uid],$userinfo[uname],$userinfo[pass],$userinfo[storynum],$userinfo[umode],$userinfo[uorder],$userinfo[thold],$userinfo[noscore],$userinfo[ublockon],$userinfo[theme],$userinfo[commentmax]);
-	Header("Location: modules.php?name=Your_Account&theme=$theme");
+	Header("Location: modules.php?name=$module_name&theme=$theme");
     }
 }
 
 function editcomm() {
-    global $user, $userinfo, $cookie;
+    global $user, $userinfo, $cookie, $module_name;
     getusrinfo($user);
     if (($userinfo[uname] != $cookie[1]) AND ($userinfo[pass] != $cookie[2])) {
     include ("header.php");
@@ -784,7 +915,7 @@ function editcomm() {
     echo "<br>";
     OpenTable();
     echo "<table cellpadding=\"8\" border=\"0\"><tr><td>"
-	."<form action=\"modules.php?name=Your_Account\" method=\"post\">"
+	."<form action=\"modules.php?name=$module_name\" method=\"post\">"
 	."<b>"._DISPLAYMODE."</b>"
 	."<select name=\"umode\">";
     ?>
@@ -834,7 +965,7 @@ function editcomm() {
 }
 
 function savecomm($uid, $uname, $umode, $uorder, $thold, $noscore, $commentmax) {
-    global $user, $cookie, $userinfo, $user_prefix, $dbi;
+    global $user, $cookie, $userinfo, $user_prefix, $dbi, $module_name;
     cookiedecode($user);
     $check = $cookie[1];
     $check2 = $cookie[2];
@@ -842,10 +973,10 @@ function savecomm($uid, $uname, $umode, $uorder, $thold, $noscore, $commentmax)
     list($vuid, $ccpass) = sql_fetch_row($result, $dbi);
     if (($uid == $vuid) AND ($check2 == $ccpass)) {	
 	if(isset($noscore)) $noscore=1; else $noscore=0;
-	sql_query("update ".$user_prefix."_users set umode='$umode', uorder='$uorder', thold='$thold', noscore='$noscore', commentmax='$commentmax' where uid=$uid", $dbi);
+	sql_query("update ".$user_prefix."_users set umode='$umode', uorder='$uorder', thold='$thold', noscore='$noscore', commentmax='$commentmax' where uid='$uid'", $dbi);
 	getusrinfo($user);
 	docookie($userinfo[uid],$userinfo[uname],$userinfo[pass],$userinfo[storynum],$userinfo[umode],$userinfo[uorder],$userinfo[thold],$userinfo[noscore],$userinfo[ublockon],$userinfo[theme],$userinfo[commentmax]);
-	Header("Location: modules.php?name=Your_Account");
+	Header("Location: modules.php?name=$module_name");
     }
 }
 
@@ -881,12 +1012,79 @@ function avatarlist() {
     include("footer.php"); 
 } 
 
+function broadcast($the_message, $who) {
+    global $prefix, $dbi, $broadcast_msg, $module_name;
+    if ($broadcast_msg == 1) {
+	include("header.php");
+	title(""._BROADCAST."");
+	OpenTable();
+	$numrows = sql_num_rows(sql_query("select * from ".$prefix."_public_messages where who='$who'", $dbi), $dbi);
+	$the_message = FixQuotes(filter_text($the_message, "nohtml"));
+	if ($the_message != "" AND $numrows == 0) {
+	    $the_time = time();
+	    $result = sql_query("INSERT INTO ".$prefix."_public_messages values (NULL, '$the_message', '$the_time', '$who')", $dbi);
+	    echo "<center>"._BROADCASTSENT."<br><br>[ <a href=\"modules.php?name=$module_name\">"._RETURNPAGE."</a> ]</center>";
+	} else {
+	    echo "<center>"._BROADCASTNOTSENT."<br><br>[ <a href=\"modules.php?name=$module_name\">"._RETURNPAGE."</a> ]</center>";
+	}
+	CloseTable();
+	include("footer.php");
+    } else {
+	echo "I don't like you...";
+    }
+}
+
+function my_headlines($hid, $url=0) {
+    global $prefix, $dbi;
+    $result = sql_query("select headlinesurl from ".$prefix."_headlines where hid='$hid'", $dbi);
+    list($url) = sql_fetch_row($result, $dbi);
+    $rdf = parse_url($url);
+    $fp = fsockopen($rdf['host'], 80, $errno, $errstr, 15);
+    if (!$fp) {
+        $content = "<font class=\"content\">Problema!</font>";
+        return;
+    }
+    if ($fp) {
+        fputs($fp, "GET " . $rdf['path'] . "?" . $rdf['query'] . " HTTP/1.0\r\n");
+        fputs($fp, "HOST: " . $rdf['host'] . "\r\n\r\n");
+        $string	= "";
+        while(!feof($fp)) {
+	    $pagetext = fgets($fp,300);
+	    $string .= chop($pagetext);
+	}
+	fputs($fp,"Connection: close\r\n\r\n");
+	fclose($fp);
+	$items = explode("</item>",$string);
+	$content = "<font class=\"content\">";
+	for ($i=0;$i<10;$i++) {
+	    $link = ereg_replace(".*<link>","",$items[$i]);
+	    $link = ereg_replace("</link>.*","",$link);
+	    $title2 = ereg_replace(".*<title>","",$items[$i]);
+	    $title2 = ereg_replace("</title>.*","",$title2);
+	    if ($items[$i] == "") {
+	        $content = "";
+	        return;
+	    } else {
+	        if (strcmp($link,$title)) {
+	    	    $cont = 1;
+		    $content .= "<img src=\"images/arrow.gif\" border=\"0\" hspace=\"5\"><a href=\"$link\" target=\"new\">$title2</a><br>\n";
+		}
+	    }
+	}
+    }
+    echo "$content";
+}
+
 switch($op) {
 
     case "logout":
 	logout();
 	break;
 
+    case "broadcast":
+	broadcast($the_message, $who);
+	break;
+
     case "lost_pass":
 	lost_pass();
 	break;
@@ -904,7 +1102,7 @@ switch($op) {
 	break;
 
     case "userinfo":
-	userinfo($uname, $bypass);
+	userinfo($uname, $bypass, $hid, $url);
 	break;
 
     case "login":
@@ -928,7 +1126,7 @@ switch($op) {
 	break;
 	
     case "savehome":
-	savehome($uid, $uname, $storynum, $ublockon, $ublock);
+	savehome($uid, $uname, $storynum, $ublockon, $ublock, $broadcast, $popmeson);
 	break;
 
     case "savetheme":
@@ -955,10 +1153,14 @@ switch($op) {
         new_user();
         break;
 
+    case "my_headlines":
+	my_headlines($hid, $url);
+	break;
+
     default:
 	main($user);
 	break;
 
 }
 
-?>
\ No newline at end of file
+?>
