@@ -176,5 +176,26 @@ define("_THANKSUSER","Thank you for registering at");
 define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
 define("_BROWSEUSERS","Browse Users");
 define("_SEARCHUSERS","Search Users");
+define("_BROADCAST","Broadcast Public Message");
+define("_BROADCASTTEXT","You can send a <i>Public Message</i> from here (255 characters max). This message will be displayed to all online users in the next 10 minutes. Any user online will see you message just once in a red bar under the site's logo. Any user can deactivate this feature from <a href=\"modules.php?name=Your_Account&amp;op=edithome\">here</a>. Please don't abuse. HTML code isn't allowed here.");
+define("_SEND","Send");
+define("_MESSAGEACTIVATE","Activate Broadcast Public Messages?");
+define("_BROADCASTSENT","Your Broadcast Message has been sent.");
+define("_BROADCASTNOTSENT","<b>ERROR:</b> Your Broadcast Message is empty or you already sent a message recently. To publish another message you need to wait about 10 minutes.");
+define("_RETURNPAGE","Return to your personal page");
+define("_MYHEADLINES","My Headlines");
+define("_SELECTASITE","Select the site from which you want to read the headlines:");
+define("_SELECTASITE2","Select a Web Site");
+define("_ORTYPEURL","Or type the headlines RSS/XML url of your prefered site:");
+define("_GO","Go");
+define("_HEADLINESFROM","Headlines from");
+define("_WEBMAIL", "WebMail");
+define("_MESSAGES","Messages");
+define("_RETURNACCOUNT", "Return to Your Account Page");
+define("_ACCESSTO", "Access to");
+define("_CREATEJOURNAL", "Create your own Journal");
+define("_READHEADLINES", "Read custom headlines");
+define("_POPMSGACTIVE","Activate Private Message PopUp?");
+define("_READMYJOURNAL","Read My Journal");
 
 ?>
\ No newline at end of file
