@@ -42,7 +42,7 @@ function FormatStory($thetext, $notes, $aid, $informant) {
 	} else {
 	    $boxstuff = "$anonymous ";
 	}
-	$boxstuff .= "".translate("writes")." <i>\"$thetext\"</i> $notes\n";
+	$boxstuff .= "writes <i>\"$thetext\"</i> $notes\n";
 	echo "<font class=\"content\" color=\"#505050\">$boxstuff</font>\n";
     }
 }
@@ -68,8 +68,10 @@ echo "<br>
 echo "
 <table cellpadding=0 cellspacing=1 border=0 width=99% bgcolor=660000><tr><td>
 <table cellpadding=5 cellspacing=1 border=0 width=100% bgcolor=FFFFFF><tr><td>
-<font class=content>$slogan</td></tr></table></td></tr></table><P>
-<table width=99% align=center cellpadding=0 cellspacing=0 border=0><tr><td valign=top rowspan=5>";
+<font class=content>$slogan</td></tr></table></td></tr></table>";
+    $public_msg = public_message();
+    echo "$public_msg<br>";	
+echo "<table width=99% align=center cellpadding=0 cellspacing=0 border=0><tr><td valign=top rowspan=5>";
 
 blocks(left);
 
@@ -88,7 +90,13 @@ footmsg();
 }
 
 function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $thetext, $notes, $morelink, $topicname, $topicimage, $topictext) {
-	global $anonymous;
+	global $anonymous, $tipath;
+    $ThemeSel = get_theme();
+    if (file_exists("themes/$ThemeSel/images/topics/$topicimage")) {
+	$t_image = "themes/$ThemeSel/images/topics/$topicimage";
+    } else {
+	$t_image = "$tipath$topicimage";
+    }
 	if ("$aid" == "$informant") { ?>
 		<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#DDDDDD"><tr valign="top" bgcolor="#660000">
 			<td><img src="themes/Slash/images/cl.gif" width="7" height="10" alt=""><img src="themes/Slash/images/pix.gif" width="4" height="4" alt=""></td>
@@ -102,7 +110,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 			<td background="themes/Slash/images/gl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%">
 				<table width="100%" border="0" cellpadding="5" cellspacing="0"><tr>
-				<td><font class="tiny"><?php echo translate("Posted by "); ?> <?php formatAidHeader($aid) ?> <?php echo translate("on"); ?> <?php echo"$datetime $timezone"; ?> (<?php echo $counter; ?> <?php echo translate("reads"); ?>)</font></td>
+				<td><font class="tiny">Posted by <?php formatAidHeader($aid) ?> on <?php echo"$datetime $timezone"; ?> (<?php echo $counter; ?> reads)</font></td>
 				</tr></table>
 			</td>
 			<td background="themes/Slash/images/gr.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
@@ -112,7 +120,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 			<td background="themes/Slash/images/wl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%"><table width="100%" border="0" cellpadding="5" cellspacing="0"><tr><td>
 			
-			<a href="modules.php?name=Search&amp;query=&topic=<?php echo"$topic"; ?>&author="><img src=<?php echo"images/topics/$topicimage"; ?> border=0 Alt=<?php echo"\"$topictext\""; ?> align=right hspace=10 vspace=10></a>
+			<a href="modules.php?name=News&amp;new_topic=<?php echo"$topic"; ?>&author="><img src=<?php echo"$t_image"; ?> border=0 Alt=<?php echo"\"$topictext\""; ?> align=right hspace=10 vspace=10></a>
 			
 			<?php echo "$thetext"; ?>
                  </td></tr></table></td>
@@ -133,7 +141,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 <?php	} else {
 		if($informant != "") $boxstuff = "<a href=\"modules.php?name=Your_Account&amp;op=userinfo&uname=$informant\">$informant</a> ";
 		else $boxstuff = "$anonymous ";
-		$boxstuff .= "".translate("writes")." <i>\"$thetext\"</i> $notes";
+		$boxstuff .= "writes <i>\"$thetext\"</i> $notes";
 ?>		<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#DDDDDD"><tr valign="top" bgcolor="#660000">
 			<td><img src="themes/Slash/images/cl.gif" width="7" height="10" alt=""><img src="themes/Slash/images/pix.gif" width="4" height="4" alt=""></td>
 			<td width="100%"><table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td>
@@ -145,7 +153,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 			<td background="themes/Slash/images/gl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%">
 				<table width="100%" border="0" cellpadding="5" cellspacing="0"><tr>
-				<td><font class="tiny"><?php echo translate("Posted by "); ?> <?php formatAidHeader($aid) ?> <?php echo translate("on"); ?> <?php echo"$datetime $timezone"; ?> (<?php echo $counter; ?> <?php echo translate("reads"); ?>)</font></td>
+				<td><font class="tiny">Posted by <?php formatAidHeader($aid) ?> on <?php echo"$datetime $timezone"; ?> (<?php echo $counter; ?> reads)</font></td>
 				</tr></table>
 			</td>
 			<td background="themes/Slash/images/gr.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
@@ -154,7 +162,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 		<tr bgcolor="#ffffff">
 			<td background="themes/Slash/images/wl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%"><table width="100%" border="0" cellpadding="5" cellspacing="0"><tr><td>
-			<a href="modules.php?name=Search&amp;query=&topic=<?php echo"$topic"; ?>&author="><img src=<?php echo"images/topics/$topicimage"; ?> border=0 Alt=<?php echo"\"$topictext\""; ?> align=right hspace=10 vspace=10></a>
+			<a href="modules.php?name=News&amp;new_topic=<?php echo"$topic"; ?>&author="><img src=<?php echo"$t_image"; ?> border=0 Alt=<?php echo"\"$topictext\""; ?> align=right hspace=10 vspace=10></a>
 			<?php echo "$boxstuff"; ?>
                  </td></tr></table></td>
                  <td background="themes/Slash/images/wr.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
@@ -174,7 +182,7 @@ function themeindex ($aid, $informant, $datetime, $title, $counter, $topic, $the
 }
 
 function themearticle ($aid, $informant, $datetime, $title, $thetext, $topic, $topicname, $topicimage, $topictext) {
-	global $admin, $sid;
+	global $admin, $sid, $tipath;
 	if ("$aid" == "$informant") { ?>
 		<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#DDDDDD"><tr valign="top" bgcolor="#660000">
 			<td><img src="themes/Slash/images/cl.gif" width="7" height="10" alt=""><img src="themes/Slash/images/pix.gif" width="4" height="4" alt=""></td>
@@ -188,11 +196,11 @@ function themearticle ($aid, $informant, $datetime, $title, $thetext, $topic, $t
 			<td background="themes/Slash/images/gl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%">
 				<table width="100%" border="0" cellpadding="5" cellspacing="0"><tr>
-				<td><font class="tiny"><?php echo translate("Posted by "); ?> <?php formatAidHeader($aid) ?> <?php echo translate("on"); ?> <?php echo"$datetime $timezone"; ?></font>
+				<td><font class="tiny">Posted by <?php formatAidHeader($aid) ?> on <?php echo"$datetime $timezone"; ?></font>
 
 <?php
 if ($admin) {
-    echo "&nbsp;&nbsp; $font2 [ <a href=admin.php?op=EditStory&sid=$sid>".translate("Edit")."</a> | <a href=admin.php?op=RemoveStory&sid=$sid>".translate("Delete")."</a> ]";
+    echo "&nbsp;&nbsp; $font2 [ <a href=admin.php?op=EditStory&sid=$sid>Edit</a> | <a href=admin.php?op=RemoveStory&sid=$sid>Delete</a> ]";
 }
 ?>
 				</td>
@@ -204,7 +212,7 @@ if ($admin) {
 		<tr bgcolor="#ffffff">
 			<td background="themes/Slash/images/wl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%"><table width="100%" border="0" cellpadding="5" cellspacing="0"><tr><td>
-		<?php echo "<a href=modules.php?name=Search&amp;query=&topic=$topic&author=><img src=images/topics/$topicimage border=0 Alt=\"$topictext\" align=right hspace=10 vspace=10></a>"; ?>
+		<?php echo "<a href=modules.php?name=News&amp;new_topic=$topic><img src=$t_image border=0 Alt=\"$topictext\" align=right hspace=10 vspace=10></a>"; ?>
 			<?php echo "$thetext"; ?>
                  </td></tr></table></td>
                  <td background="themes/Slash/images/wr.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
@@ -214,7 +222,7 @@ if ($admin) {
 <?php	} else {
 		if($informant != "") $boxstuff = "<a href=\"modules.php?name=Your_Account&amp;op=userinfo&uname=$informant\">$informant</a> ";
 		else $boxstuff = "$anonymous ";
-		$boxstuff .= "".translate("writes")." <i>\"$thetext\"</i> $notes";
+		$boxstuff .= "writes <i>\"$thetext\"</i> $notes";
 ?>		<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#DDDDDD"><tr valign="top" bgcolor="#660000">
 			<td><img src="themes/Slash/images/cl.gif" width="7" height="10" alt=""><img src="themes/Slash/images/pix.gif" width="4" height="4" alt=""></td>
 			<td width="100%">
@@ -227,7 +235,7 @@ if ($admin) {
 			<td background="themes/Slash/images/gl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%">
 				<table width="100%" border="0" cellpadding="5" cellspacing="0"><tr>
-				<td><font class="tiny"><?php echo translate("Posted by "); ?> <?php formatAidHeader($aid) ?> <?php echo translate("on"); ?> <?php echo"$datetime $timezone"; ?></font>
+				<td><font class="tiny">Posted by <?php formatAidHeader($aid) ?> on <?php echo"$datetime $timezone"; ?></font>
 				
 <?php
 if ($admin) {
@@ -235,7 +243,7 @@ if ($admin) {
 }
 ?>
 <br><?php echo "$font1"; ?>
-<?php echo "".translate("Contributed by ").""; ?> <?php echo "<a href=\"modules.php?name=Your_Account&amp;op=userinfo&uname=$informant\">$informant</a>"; ?>
+<?php echo "Contributed by <?php echo "<a href=\"modules.php?name=Your_Account&amp;op=userinfo&uname=$informant\">$informant</a>"; ?>
 				</td>
 				</tr></table>
 			</td>
@@ -245,7 +253,7 @@ if ($admin) {
 		<tr bgcolor="#ffffff">
 			<td background="themes/Slash/images/wl.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
 			<td width="100%"><table width="100%" border="0" cellpadding="5" cellspacing="0"><tr><td>
-		<?php echo "<a href=modules.php?name=Search&amp;query=&topic=$topic&author=><img src=images/topics/$topicimage border=0 Alt=\"$topictext\" align=right hspace=10 vspace=10></a>"; ?>
+		<?php echo "<a href=modules.php?name=News&amp;new_topic=$topic><img src=$t_image border=0 Alt=\"$topictext\" align=right hspace=10 vspace=10></a>"; ?>
 			<?php echo "$thetext"; ?>
                  </td></tr></table></td>
                  <td background="themes/Slash/images/wr.gif"><img src="themes/Slash/images/pix.gif" width="11" height="11" alt=""></td>
